@@ -7,6 +7,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #include "api/api_media.h"
 
+#include "api/api_common.h"
 #include "data/data_document.h"
 #include "data/stickers/data_stickers_set.h"
 #include "history/history_item.h"
@@ -74,41 +75,39 @@ MTPVector<MTPDocumentAttribute> ComposeSendingDocumentAttributes(
 
 } // namespace
 
-MTPInputMedia PrepareUploadedPhoto(
-		const MTPInputFile &file,
-		std::vector<MTPInputDocument> attachedStickers) {
-	const auto flags = attachedStickers.empty()
+MTPInputMedia PrepareUploadedPhoto(RemoteFileInfo info) {
+	const auto flags = info.attachedStickers.empty()
 		? MTPDinputMediaUploadedPhoto::Flags(0)
 		: MTPDinputMediaUploadedPhoto::Flag::f_stickers;
 	return MTP_inputMediaUploadedPhoto(
 		MTP_flags(flags),
-		file,
-		MTP_vector<MTPInputDocument>(ranges::to<QVector>(attachedStickers)),
+		info.file,
+		MTP_vector<MTPInputDocument>(
+			ranges::to<QVector>(info.attachedStickers)),
 		MTP_int(0));
 }
 
 MTPInputMedia PrepareUploadedDocument(
 		not_null<HistoryItem*> item,
-		const MTPInputFile &file,
-		const std::optional<MTPInputFile> &thumb,
-		std::vector<MTPInputDocument> attachedStickers) {
+		RemoteFileInfo info) {
 	if (!item || !item->media() || !item->media()->document()) {
 		return MTP_inputMediaEmpty();
 	}
 	const auto emptyFlag = MTPDinputMediaUploadedDocument::Flags(0);
 	using DocFlags = MTPDinputMediaUploadedDocument::Flag;
 	const auto flags = emptyFlag
-		| (thumb ? DocFlags::f_thumb : emptyFlag)
+		| (info.thumb ? DocFlags::f_thumb : emptyFlag)
 		| (item->groupId() ? DocFlags::f_nosound_video : emptyFlag)
-		| (attachedStickers.empty() ? DocFlags::f_stickers : emptyFlag);
+		| (info.attachedStickers.empty() ? DocFlags::f_stickers : emptyFlag);
 	const auto document = item->media()->document();
 	return MTP_inputMediaUploadedDocument(
 		MTP_flags(flags),
-		file,
-		thumb.value_or(MTPInputFile()),
+		info.file,
+		info.thumb.value_or(MTPInputFile()),
 		MTP_string(document->mimeString()),
 		ComposeSendingDocumentAttributes(document),
-		MTP_vector<MTPInputDocument>(ranges::to<QVector>(attachedStickers)),
+		MTP_vector<MTPInputDocument>(
+			ranges::to<QVector>(info.attachedStickers)),
 		MTP_int(0));
 }
 
