@@ -196,7 +196,6 @@ public:
 		const QString &hash,
 		FnMut<void(const MTPChatInvite &)> done,
 		Fn<void(const MTP::Error &)> fail);
-	void importChatInvite(const QString &hash, bool isGroup);
 
 	void processFullPeer(
 		not_null<PeerData*> peer,
@@ -325,7 +324,8 @@ public:
 	void sendInlineResult(
 		not_null<UserData*> bot,
 		not_null<InlineBots::Result*> data,
-		const SendAction &action);
+		const SendAction &action,
+		std::optional<MsgId> localMessageId);
 	void sendMessageFail(
 		const MTP::Error &error,
 		not_null<PeerData*> peer,
@@ -357,6 +357,8 @@ public:
 
 	void updatePrivacyLastSeens();
 
+	static constexpr auto kJoinErrorDuration = 5 * crl::time(1000);
+
 private:
 	struct MessageDataRequest {
 		using Callbacks = std::vector<Fn<void()>>;
