@@ -238,6 +238,8 @@ void EditCaptionBox::rebuildPreview() {
 }
 
 void EditCaptionBox::setupField() {
+	const auto show = std::make_shared<Window::Show>(_controller);
+	const auto session = &_controller->session();
 	_field->setMaxLength(
 		_controller->session().serverConfig().captionLengthMax);
 	_field->setSubmitSettings(
@@ -247,10 +249,10 @@ void EditCaptionBox::setupField() {
 		Core::App().settings().replaceEmojiValue());
 	_field->setMarkdownReplacesEnabled(rpl::single(true));
 	_field->setEditLinkCallback(
-		DefaultEditLinkCallback(_controller, _field));
+		DefaultEditLinkCallback(show, session, _field));
 	_field->setMaxHeight(st::confirmCaptionArea.heightMax);
 
-	InitSpellchecker(_controller, _field);
+	InitSpellchecker(show, session, _field);
 
 	connect(_field, &Ui::InputField::submitted, [=] { save(); });
 	connect(_field, &Ui::InputField::cancelled, [=] { closeBox(); });
@@ -307,7 +309,7 @@ void EditCaptionBox::setupShadows() {
 
 void EditCaptionBox::setupControls() {
 	auto hintLabelToggleOn = _previewRebuilds.events_starting_with(
-		rpl::empty_value()
+		{}
 	) | rpl::map([=] {
 		return _controller->session().settings().photoEditorHintShown()
 			? _isPhoto
@@ -332,9 +334,7 @@ void EditCaptionBox::setupControls() {
 			st::defaultBoxCheckbox),
 		st::editMediaCheckboxMargins)
 	)->toggleOn(
-		_previewRebuilds.events_starting_with(
-			rpl::empty_value()
-		) | rpl::map([=] {
+		_previewRebuilds.events_starting_with({}) | rpl::map([=] {
 			return _isPhoto
 				&& CanBeCompressed(_albumType)
 				&& !_preparedList.files.empty();
@@ -410,9 +410,14 @@ void EditCaptionBox::setupPhotoEditorEventHandler() {
 			controller->session().settings().incrementPhotoEditorHintShown();
 			controller->session().saveSettings();
 		};
+		const auto clearError = [=] {
+			_error = QString();
+			update();
+		};
 		const auto previewWidth = st::sendMediaPreviewSize;
 		if (!_preparedList.files.empty()) {
 			increment();
+			clearError();
 			Editor::OpenWithPreparedFile(
 				this,
 				controller,
@@ -425,6 +430,7 @@ void EditCaptionBox::setupPhotoEditorEventHandler() {
 				return;
 			}
 			increment();
+			clearError();
 			auto callback = [=](const Editor::PhotoModifications &mods) {
 				if (!mods || !_photoMedia) {
 					return;
@@ -580,6 +586,7 @@ void EditCaptionBox::captionResized() {
 
 void EditCaptionBox::updateBoxSize() {
 	auto footerHeight = 0;
+	footerHeight += st::normalFont->height + errorTopSkip();
 	if (_field) {
 		footerHeight += st::boxPhotoCaptionSkip + _field->height();
 	}
@@ -613,8 +620,24 @@ void EditCaptionBox::paintEvent(QPaintEvent *e) {
 void EditCaptionBox::resizeEvent(QResizeEvent *e) {
 	BoxContent::resizeEvent(e);
 
+	const auto errorHeight = st::normalFont->height + errorTopSkip();
 	auto bottom = height();
+	{
+		const auto resultScrollHeight = bottom
+			- _field->height()
+			- st::boxPhotoCaptionSkip
+			- (_controls->isHidden() ? 0 : _controls->heightNoMargins())
+			- st::boxPhotoPadding.top()
+			- errorHeight;
+		const auto minThumbH = st::sendBoxAlbumGroupSize.height()
+			+ st::sendBoxAlbumGroupSkipTop * 2;
+		const auto diff = resultScrollHeight - minThumbH;
+		if (diff < 0) {
+			bottom -= diff;
+		}
+	}
 
+	bottom -= errorHeight;
 	_field->resize(st::sendMediaPreviewSize, _field->height());
 	_field->moveToLeft(
 		st::boxPhotoPadding.left(),
@@ -670,8 +693,14 @@ void EditCaptionBox::save() {
 	options.scheduled = item->isScheduled() ? item->date() : 0;
 
 	if (!_preparedList.files.empty()) {
-		auto action = Api::SendAction(item->history());
-		action.options = options;
+		if ((_albumType != Ui::AlbumType::None)
+				&& !_preparedList.files.front().canBeInAlbumType(
+					_albumType)) {
+			_error = tr::lng_edit_media_album_error(tr::now);
+			update();
+			return;
+		}
+		auto action = Api::SendAction(item->history(), options);
 		action.replaceMediaOf = item->fullId().msg;
 
 		Storage::ApplyModifications(_preparedList);
