@@ -10,6 +10,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/widgets/checkbox.h"
 #include "ui/widgets/labels.h"
 #include "ui/widgets/buttons.h"
+#include "ui/text/text_utilities.h"
 #include "ui/wrap/slide_wrap.h"
 #include "ui/wrap/vertical_layout.h"
 #include "history/history.h"
@@ -201,28 +202,44 @@ Ui::Radioenum<EditPrivacyBox::Option> *EditPrivacyBox::AddOption(
 			group,
 			option,
 			controller->optionLabel(option),
-			st::settingsSendType),
-		st::settingsSendTypePadding);
+			st::settingsPrivacyOption),
+		(st::settingsSendTypePadding + style::margins(
+			-st::lineWidth,
+			st::settingsPrivacySkipTop,
+			0,
+			0)));
 }
 
 Ui::FlatLabel *EditPrivacyBox::addLabel(
 		not_null<Ui::VerticalLayout*> container,
-		rpl::producer<QString> text) {
-	const auto wrap = container->add(
-		object_ptr<Ui::SlideWrap<Ui::FlatLabel>>(
+		rpl::producer<TextWithEntities> text,
+		int topSkip) {
+	if (!text) {
+		return nullptr;
+	}
+	return container->add(
+		object_ptr<Ui::DividerLabel>(
 			container,
 			object_ptr<Ui::FlatLabel>(
 				container,
 				rpl::duplicate(text),
 				st::boxDividerLabel),
-			st::settingsPrivacyEditLabelPadding));
-	wrap->hide(anim::type::instant);
-	wrap->toggleOn(std::move(
-		text
-	) | rpl::map([](const QString &text) {
-		return !text.isEmpty();
-	}));
-	return wrap->entity();
+			st::settingsDividerLabelPadding),
+		{ 0, topSkip, 0, 0 }
+	)->entity();
+}
+
+Ui::FlatLabel *EditPrivacyBox::addLabelOrDivider(
+		not_null<Ui::VerticalLayout*> container,
+		rpl::producer<TextWithEntities> text,
+		int topSkip) {
+	if (const auto result = addLabel(container, std::move(text), topSkip)) {
+		return result;
+	}
+	container->add(
+		object_ptr<Ui::BoxContentDivider>(container),
+		{ 0, topSkip, 0, 0 });
+	return nullptr;
 }
 
 void EditPrivacyBox::setupContent() {
@@ -252,9 +269,7 @@ void EditPrivacyBox::setupContent() {
 	};
 	const auto addExceptionLink = [=](Exception exception) {
 		const auto update = Ui::CreateChild<rpl::event_stream<>>(content);
-		auto label = update->events_starting_with(
-			rpl::empty_value()
-		) | rpl::map([=] {
+		auto label = update->events_starting_with({}) | rpl::map([=] {
 			return Settings::ExceptionUsersCount(exceptions(exception));
 		}) | rpl::map([](int count) {
 			return count
@@ -262,13 +277,20 @@ void EditPrivacyBox::setupContent() {
 				: tr::lng_edit_privacy_exceptions_add(tr::now);
 		});
 		auto text = _controller->exceptionButtonTextKey(exception);
+		const auto always = (exception == Exception::Always);
 		const auto button = content->add(
 			object_ptr<Ui::SlideWrap<Button>>(
 				content,
-				object_ptr<Button>(
+				CreateButton(
 					content,
 					rpl::duplicate(text),
-					st::settingsButton)));
+					st::settingsButton,
+					{
+						(always
+							? &st::settingsIconPlus
+							: &st::settingsIconMinus),
+						always ? kIconGreen : kIconRed,
+					})));
 		CreateRightLabel(
 			button->entity(),
 			std::move(label),
@@ -286,17 +308,26 @@ void EditPrivacyBox::setupContent() {
 
 	auto above = _controller->setupAboveWidget(
 		content,
-		rpl::duplicate(optionValue));
+		rpl::duplicate(optionValue),
+		getDelegate()->outerContainer());
 	if (above) {
 		content->add(std::move(above));
 	}
 
-	AddSubsectionTitle(content, _controller->optionsTitleKey());
+	AddSubsectionTitle(
+		content,
+		_controller->optionsTitleKey(),
+		{ 0, st::settingsPrivacySkipTop, 0, 0 });
 	addOptionRow(Option::Everyone);
 	addOptionRow(Option::Contacts);
 	addOptionRow(Option::Nobody);
-	addLabel(content, _controller->warning());
-	AddSkip(content);
+	const auto warning = addLabelOrDivider(
+		content,
+		_controller->warning(),
+		st::settingsSectionSkip + st::settingsPrivacySkipTop);
+	if (warning) {
+		_controller->prepareWarningLabel(warning);
+	}
 
 	auto middle = _controller->setupMiddleWidget(
 		_window,
@@ -306,13 +337,17 @@ void EditPrivacyBox::setupContent() {
 		content->add(std::move(middle));
 	}
 
-	AddDivider(content);
 	AddSkip(content);
-	AddSubsectionTitle(content, tr::lng_edit_privacy_exceptions());
+	AddSubsectionTitle(
+		content,
+		tr::lng_edit_privacy_exceptions(),
+		{ 0, st::settingsPrivacySkipTop, 0, 0 });
 	const auto always = addExceptionLink(Exception::Always);
 	const auto never = addExceptionLink(Exception::Never);
-	addLabel(content, _controller->exceptionsDescription());
-	AddSkip(content);
+	addLabel(
+		content,
+		_controller->exceptionsDescription() | Ui::Text::ToWithEntities(),
+		st::settingsSectionSkip);
 
 	if (auto below = _controller->setupBelowWidget(_window, content)) {
 		content->add(std::move(below));
