@@ -167,6 +167,7 @@ LocalStorageBox::Row::Row(
 	sizeText(data),
 	st::localStorageRowSize)
 , _clear(this, std::move(clear), st::localStorageClear) {
+	_clear->setTextTransform(Ui::RoundButton::TextTransform::NoTransform);
 	_clear->setVisible(data.count != 0);
 }
 
@@ -516,7 +517,7 @@ void LocalStorageBox::updateMediaLabel() {
 }
 
 void LocalStorageBox::setupLimits(not_null<Ui::VerticalLayout*> container) {
-	const auto shadow = container->add(
+	container->add(
 		object_ptr<Ui::PlainShadow>(container),
 		st::localStorageRowPadding);
 
