@@ -11,6 +11,10 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "mtproto/sender.h"
 #include "core/core_cloud_password.h"
 
+namespace MTP {
+class Instance;
+} // namespace MTP
+
 namespace Main {
 class Session;
 } // namespace Main
@@ -35,6 +39,7 @@ public:
 		Core::CloudPasswordCheckRequest curRequest;
 		Core::CloudPasswordAlgo newAlgo;
 		bool hasRecovery = false;
+		QString fromRecoveryCode;
 		bool notEmptyPassport = false;
 		QString hint;
 		Core::SecureSecretAlgo newSecureSecretAlgo;
@@ -47,6 +52,11 @@ public:
 		std::optional<QString> customDescription;
 		rpl::producer<QString> customSubmitButton;
 	};
+	PasscodeBox(
+		QWidget*,
+		not_null<MTP::Instance*> mtp,
+		Main::Session *session,
+		const CloudFields &fields);
 	PasscodeBox(
 		QWidget*,
 		not_null<Main::Session*> session,
@@ -56,6 +66,8 @@ public:
 	rpl::producer<> passwordReloadNeeded() const;
 	rpl::producer<> clearUnconfirmedPassword() const;
 
+	rpl::producer<MTPauth_Authorization> newAuthorization() const;
+
 	bool handleCustomCheckError(const MTP::Error &error);
 	bool handleCustomCheckError(const QString &type);
 
@@ -83,7 +95,9 @@ private:
 	bool onlyCheckCurrent() const;
 
 	void setPasswordDone(const QByteArray &newPasswordBytes);
-	void setPasswordFail(const MTP::Error &error);
+	void recoverPasswordDone(
+		const QByteArray &newPasswordBytes,
+		const MTPauth_Authorization &result);
 	void setPasswordFail(const QString &type);
 	void setPasswordFail(
 		const QByteArray &newPasswordBytes,
@@ -132,7 +146,7 @@ private:
 	void passwordChecked();
 	void serverError();
 
-	const not_null<Main::Session*> _session;
+	Main::Session *_session = nullptr;
 	MTP::Sender _api;
 
 	QString _pattern;
@@ -163,6 +177,7 @@ private:
 	QString _oldError, _newError, _emailError;
 
 	rpl::event_stream<QByteArray> _newPasswordSet;
+	rpl::event_stream<MTPauth_Authorization> _newAuthorization;
 	rpl::event_stream<> _passwordReloadNeeded;
 	rpl::event_stream<> _clearUnconfirmedPassword;
 
@@ -172,14 +187,14 @@ class RecoverBox final : public Ui::BoxContent {
 public:
 	RecoverBox(
 		QWidget*,
-		not_null<Main::Session*> session,
+		not_null<MTP::Instance*> mtp,
+		Main::Session *session,
 		const QString &pattern,
-		bool notEmptyPassport,
-		bool hasPendingReset,
+		const PasscodeBox::CloudFields &fields,
 		Fn<void()> closeParent = nullptr);
 
-	rpl::producer<> passwordCleared() const;
-	rpl::producer<> recoveryExpired() const;
+	[[nodiscard]] rpl::producer<QByteArray> newPasswordSet() const;
+	[[nodiscard]] rpl::producer<> recoveryExpired() const;
 
 	//void reloadPassword();
 	//void recoveryExpired();
@@ -194,15 +209,18 @@ protected:
 private:
 	void submit();
 	void codeChanged();
-	void codeSubmitDone(const MTPauth_Authorization &result);
-	void codeSubmitFail(const MTP::Error &error);
+	void proceedToClear();
+	void proceedToChange(const QString &code);
+	void checkSubmitFail(const MTP::Error &error);
 	void setError(const QString &error);
 
+	Main::Session *_session = nullptr;
 	MTP::Sender _api;
 	mtpRequestId _submitRequest = 0;
 
 	QString _pattern;
-	bool _notEmptyPassport = false;
+
+	PasscodeBox::CloudFields _cloudFields;
 
 	object_ptr<Ui::InputField> _recoverCode;
 	object_ptr<Ui::LinkButton> _noEmailAccess;
@@ -210,7 +228,7 @@ private:
 
 	QString _error;
 
-	rpl::event_stream<> _passwordCleared;
+	rpl::event_stream<QByteArray> _newPasswordSet;
 	rpl::event_stream<> _recoveryExpired;
 
 };
@@ -225,6 +243,6 @@ struct RecoveryEmailValidation {
 	const QString &pattern);
 
 [[nodiscard]] object_ptr<Ui::GenericBox> PrePasswordErrorBox(
-	const MTP::Error &error,
+	const QString &error,
 	not_null<Main::Session*> session,
 	TextWithEntities &&about);
