@@ -13,4 +13,7 @@ class PeerData;
 
 void ManageInviteLinksBox(
 	not_null<Ui::GenericBox*> box,
-	not_null<PeerData*> peer);
+	not_null<PeerData*> peer,
+	not_null<UserData*> admin,
+	int count,
+	int revokedCount);
