@@ -22,9 +22,14 @@ class Session;
 
 class SelfDestructionBox : public Ui::BoxContent {
 public:
+	enum class Type {
+		Account,
+		Sessions,
+	};
 	SelfDestructionBox(
 		QWidget*,
 		not_null<Main::Session*> session,
+		Type type,
 		rpl::producer<int> preloaded);
 
 	static QString DaysLabel(int days);
@@ -36,6 +41,7 @@ private:
 	void gotCurrent(int days);
 	void showContent();
 
+	const Type _type;
 	const not_null<Main::Session*> _session;
 	bool _prepared = false;
 	std::vector<int> _ttlValues;
