@@ -29,6 +29,7 @@ namespace Calls::Group {
 struct JoinInfo;
 class Panel;
 class ChooseJoinAsProcess;
+class StartRtmpProcess;
 } // namespace Calls::Group
 
 namespace tgcalls {
@@ -43,6 +44,19 @@ class GroupCall;
 class Panel;
 struct DhConfig;
 
+struct StartGroupCallArgs {
+	enum class JoinConfirm {
+		None,
+		IfNowInAnother,
+		Always,
+	};
+	QString joinHash;
+	JoinConfirm confirm = JoinConfirm::IfNowInAnother;
+	bool scheduleNeeded = false;
+	bool rtmpNeeded = false;
+	bool useRtmp = false;
+};
+
 class Instance final : public base::has_weak_ptr {
 public:
 	Instance();
@@ -51,8 +65,7 @@ public:
 	void startOutgoingCall(not_null<UserData*> user, bool video);
 	void startOrJoinGroupCall(
 		not_null<PeerData*> peer,
-		const QString &joinHash = QString(),
-		bool confirmNeeded = false);
+		const StartGroupCallArgs &args);
 	void handleUpdate(
 		not_null<Main::Session*> session,
 		const MTPUpdate &update);
@@ -139,6 +152,7 @@ private:
 	base::flat_map<QString, std::unique_ptr<Media::Audio::Track>> _tracks;
 
 	const std::unique_ptr<Group::ChooseJoinAsProcess> _chooseJoinAs;
+	const std::unique_ptr<Group::StartRtmpProcess> _startWithRtmp;
 
 	base::flat_set<std::unique_ptr<crl::semaphore>> _asyncWaiters;
 
