@@ -137,7 +137,7 @@ void Userpic::processPhoto() {
 		_photo->wanted(Data::PhotoSize::Thumbnail, _peer->userpicPhotoOrigin());
 	} else {
 		_photo = nullptr;
-		if (_peer->userpicPhotoUnknown() || (photo && !photo->date)) {
+		if (_peer->userpicPhotoUnknown() || (photo && photo->isNull())) {
 			_peer->session().api().requestFullPeer(_peer);
 		}
 	}
@@ -165,8 +165,11 @@ void Userpic::refreshPhoto() {
 void Userpic::createCache(Image *image) {
 	const auto size = this->size();
 	const auto real = size * cIntRetinaFactor();
-	auto options = Images::Option::Smooth | Images::Option::Circled;
-	// _useTransparency ? (Images::Option::RoundedLarge | Images::Option::RoundedTopLeft | Images::Option::RoundedTopRight | Images::Option::Smooth) : Images::Option::None;
+	//_useTransparency
+	//	? (Images::Option::RoundLarge
+	//		| Images::Option::RoundSkipBottomLeft
+	//		| Images::Option::RoundSkipBottomRight)
+	//	: Images::Option::None;
 	if (image) {
 		auto width = image->width();
 		auto height = image->height();
@@ -178,14 +181,16 @@ void Userpic::createCache(Image *image) {
 			width = real;
 		}
 		_userPhoto = image->pixNoCache(
-			width,
-			height,
-			options,
-			size,
-			size);
+			{ width, height },
+			{
+				.options = Images::Option::RoundCircle,
+				.outer = { size, size },
+			});
 		_userPhoto.setDevicePixelRatio(cRetinaFactor());
 	} else {
-		auto filled = QImage(QSize(real, real), QImage::Format_ARGB32_Premultiplied);
+		auto filled = QImage(
+			QSize(real, real),
+			QImage::Format_ARGB32_Premultiplied);
 		filled.setDevicePixelRatio(cRetinaFactor());
 		filled.fill(Qt::transparent);
 		{
@@ -195,7 +200,10 @@ void Userpic::createCache(Image *image) {
 				_peer->name
 			).paint(p, 0, 0, size, size);
 		}
-		//Images::prepareRound(filled, ImageRoundRadius::Large, RectPart::TopLeft | RectPart::TopRight);
+		//_userPhoto = Images::PixmapFast(Images::Round(
+		//	std::move(filled),
+		//	ImageRoundRadius::Large,
+		//	RectPart::TopLeft | RectPart::TopRight));
 		_userPhoto = Images::PixmapFast(std::move(filled));
 	}
 
