@@ -27,6 +27,7 @@ public:
 
 	enum class Context {
 		Create,
+		CreateScheduled,
 		Join,
 		JoinWithConfirm,
 		Switch,
@@ -41,6 +42,10 @@ public:
 		PeerData *changingJoinAsFrom = nullptr);
 
 private:
+	void requestList();
+	void processList(std::vector<not_null<PeerData*>> &&list);
+	void finish(JoinInfo info);
+
 	struct ChannelsListRequest {
 		not_null<PeerData*> peer;
 		Fn<void(object_ptr<Ui::BoxContent>)> showBox;
@@ -51,6 +56,7 @@ private:
 		rpl::lifetime lifetime;
 		Context context = Context();
 		mtpRequestId id = 0;
+		PeerData *changingJoinAsFrom = nullptr;
 	};
 	std::unique_ptr<ChannelsListRequest> _request;
 
