@@ -48,6 +48,7 @@ struct VolumeRequest;
 struct ParticipantState;
 struct JoinInfo;
 struct RejoinEvent;
+struct RtmpInfo;
 enum class VideoQuality;
 enum class Error;
 } // namespace Group
@@ -97,6 +98,7 @@ struct VideoEndpoint {
 	PeerData *peer = nullptr;
 	std::string id;
 
+	[[nodiscard]] bool rtmp() const noexcept;
 	[[nodiscard]] bool empty() const noexcept {
 		Expects(id.empty() || peer != nullptr);
 
@@ -230,11 +232,20 @@ public:
 		return _scheduleDate;
 	}
 	[[nodiscard]] bool scheduleStartSubscribed() const;
+	[[nodiscard]] bool rtmp() const;
+	[[nodiscard]] bool listenersHidden() const;
+	[[nodiscard]] bool emptyRtmp() const;
+	[[nodiscard]] rpl::producer<bool> emptyRtmpValue() const;
+	[[nodiscard]] int rtmpVolume() const;
+
+	[[nodiscard]] Group::RtmpInfo rtmpInfo() const;
+
+	void setRtmpInfo(const Group::RtmpInfo &value);
 
 	[[nodiscard]] Data::GroupCall *lookupReal() const;
 	[[nodiscard]] rpl::producer<not_null<Data::GroupCall*>> real() const;
 
-	void start(TimeId scheduleDate);
+	void start(TimeId scheduleDate, bool rtmp);
 	void hangup();
 	void discard();
 	void rejoinAs(Group::JoinInfo info);
@@ -406,6 +417,7 @@ public:
 private:
 	class LoadPartTask;
 	class MediaChannelDescriptionsTask;
+	class RequestCurrentTimeTask;
 	using GlobalShortcutValue = base::GlobalShortcutValue;
 	using Error = Group::Error;
 	struct SinkPointer;
@@ -460,6 +472,10 @@ private:
 		std::shared_ptr<MediaChannelDescriptionsTask> task);
 	void mediaChannelDescriptionsCancel(
 		not_null<MediaChannelDescriptionsTask*> task);
+	void requestCurrentTimeStart(
+		std::shared_ptr<RequestCurrentTimeTask> task);
+	void requestCurrentTimeCancel(
+		not_null<RequestCurrentTimeTask*> task);
 	[[nodiscard]] int64 approximateServerTimeInMs() const;
 
 	[[nodiscard]] bool mediaChannelDescriptionsFill(
@@ -567,10 +583,14 @@ private:
 	MTP::DcId _broadcastDcId = 0;
 	base::flat_map<not_null<LoadPartTask*>, LoadingPart> _broadcastParts;
 	base::flat_set<
-		std::shared_ptr<
-			MediaChannelDescriptionsTask>,
+		std::shared_ptr<MediaChannelDescriptionsTask>,
 		base::pointer_comparator<
 			MediaChannelDescriptionsTask>> _mediaChannelDescriptionses;
+	base::flat_set<
+		std::shared_ptr<RequestCurrentTimeTask>,
+		base::pointer_comparator<
+			RequestCurrentTimeTask>> _requestCurrentTimes;
+	mtpRequestId _requestCurrentTimeRequestId = 0;
 
 	rpl::variable<not_null<PeerData*>> _joinAs;
 	std::vector<not_null<PeerData*>> _possibleJoinAs;
@@ -578,9 +598,13 @@ private:
 	int64 _serverTimeMs = 0;
 	crl::time _serverTimeMsGotAt = 0;
 
+	QString _rtmpUrl;
+	QString _rtmpKey;
+
 	rpl::variable<MuteState> _muted = MuteState::Muted;
 	rpl::variable<bool> _canManage = false;
 	rpl::variable<bool> _videoIsWorking = false;
+	rpl::variable<bool> _emptyRtmp = false;
 	bool _initialMuteStateSent = false;
 	bool _acceptFields = false;
 
@@ -648,6 +672,9 @@ private:
 	base::Timer _pushToTalkCancelTimer;
 	base::Timer _connectingSoundTimer;
 	bool _hadJoinedState = false;
+	bool _listenersHidden = false;
+	bool _rtmp = false;
+	int _rtmpVolume = 0;
 
 	std::unique_ptr<Webrtc::MediaDevices> _mediaDevices;
 	QString _audioInputId;
