@@ -130,10 +130,10 @@ private:
 
 	bool handleClose();
 	void startScheduledNow();
-	void trackControls(bool track);
+	void toggleFullScreen();
+	void trackControls(bool track, bool force = false);
 	void raiseControls();
 	void enlargeVideo();
-	void minimizeVideo();
 
 	void trackControl(Ui::RpWidget *widget, rpl::lifetime &lifetime);
 	void trackControlOver(not_null<Ui::RpWidget*> control, bool over);
@@ -152,6 +152,7 @@ private:
 	void updateButtonsStyles();
 	void updateMembersGeometry();
 	void refreshControlsBackground();
+	void refreshTitleBackground();
 	void setupControlsBackgroundWide();
 	void setupControlsBackgroundNarrow();
 	void showControls();
@@ -159,6 +160,8 @@ private:
 	void refreshVideoButtons(
 		std::optional<bool> overrideWideMode = std::nullopt);
 	void refreshTopButton();
+	void createPinOnTop();
+	void setupEmptyRtmp();
 	void toggleWideControls(bool shown);
 	void updateWideControlsVisibility();
 	[[nodiscard]] bool videoButtonInNarrowMode() const;
@@ -175,6 +178,7 @@ private:
 	[[nodiscard]] QRect computeTitleRect() const;
 	void refreshTitle();
 	void refreshTitleGeometry();
+	void refreshTitleColors();
 	void setupRealCallViewers();
 	void subscribeToChanges(not_null<Data::GroupCall*> real);
 
@@ -197,31 +201,37 @@ private:
 	Ui::GL::Window _window;
 	const std::unique_ptr<Ui::LayerManager> _layerBg;
 	rpl::variable<PanelMode> _mode;
+	rpl::variable<bool> _fullScreenOrMaximized = false;
 
 #ifndef Q_OS_MAC
-	std::unique_ptr<Ui::Platform::SeparateTitleControls> _controls;
+	rpl::variable<int> _controlsTop = 0;
+	const std::unique_ptr<Ui::Platform::SeparateTitleControls> _controls;
 #endif // !Q_OS_MAC
 
 	const std::unique_ptr<base::PowerSaveBlocker> _powerSaveBlocker;
 
 	rpl::lifetime _callLifetime;
 
+	object_ptr<Ui::RpWidget> _titleBackground = { nullptr };
 	object_ptr<Ui::FlatLabel> _title = { nullptr };
+	object_ptr<Ui::FlatLabel> _titleSeparator = { nullptr };
+	object_ptr<Ui::FlatLabel> _viewers = { nullptr };
 	object_ptr<Ui::FlatLabel> _subtitle = { nullptr };
 	object_ptr<Ui::AbstractButton> _recordingMark = { nullptr };
 	object_ptr<Ui::IconButton> _menuToggle = { nullptr };
+	object_ptr<Ui::IconButton> _pinOnTop = { nullptr };
 	object_ptr<Ui::DropdownMenu> _menu = { nullptr };
 	rpl::variable<bool> _wideMenuShown = false;
 	object_ptr<Ui::AbstractButton> _joinAsToggle = { nullptr };
 	object_ptr<Members> _members = { nullptr };
 	std::unique_ptr<Viewport> _viewport;
-	rpl::lifetime _trackControlsLifetime;
 	rpl::lifetime _trackControlsOverStateLifetime;
 	rpl::lifetime _trackControlsMenuLifetime;
 	object_ptr<Ui::FlatLabel> _startsIn = { nullptr };
 	object_ptr<Ui::RpWidget> _countdown = { nullptr };
 	std::shared_ptr<Ui::GroupCallScheduledLeft> _countdownData;
 	object_ptr<Ui::FlatLabel> _startsWhen = { nullptr };
+	object_ptr<Ui::RpWidget> _emptyRtmp = { nullptr };
 	ChooseJoinAsProcess _joinAsProcess;
 	std::optional<QRect> _lastSmallGeometry;
 	std::optional<QRect> _lastLargeGeometry;
@@ -251,6 +261,10 @@ private:
 
 	std::unique_ptr<MicLevelTester> _micLevelTester;
 
+	style::complex_color _controlsBackgroundColor;
+	base::Timer _hideControlsTimer;
+	rpl::lifetime _hideControlsTimerLifetime;
+
 	rpl::lifetime _peerLifetime;
 
 };
