@@ -78,6 +78,33 @@ std::map<int, const char*> BetaLogs() {
 		"- Add snap layouts support on Windows 11.\n"
 		
 		"- Fix crash in drafts after accounts switching.\n"
+	},
+	{
+		3005003,
+		"- Check the status of media and file downloads by clicking "
+		"on the new panel in the bottom of the chats list.\n"
+
+		"- View recently downloaded files "
+		"from the new Settings > Advanced > Downloads section.\n"
+
+		"- Manage Live Streams in your groups and channels "
+		"using external software like OBS Studio or XSplit Broadcaster.\n"
+	},
+	{
+		3005005,
+		"- Support stereo audio output in RTMP streams.\n"
+
+		"- Improve RTMP stream full screen mode.\n"
+
+		"- Fix a couple of crashes.\n"
+	},
+	{
+		3005006,
+		"- Show viewers count in RTMP streams.\n"
+		"- Send GIFs search results without \"via @bot\".\n"
+		"- Display the file thumbnail in downloads bar.\n"
+		"- Always try to save original photo bytes to disk.\n"
+		"- Fix crash when deleting a user from your contacts list.\n"
 	}
 	};
 };
