@@ -148,7 +148,8 @@ public:
 	}
 	void setGroupCall(
 		const MTPInputGroupCall &call,
-		TimeId scheduleDate = 0);
+		TimeId scheduleDate = 0,
+		bool rtmp = false);
 	void clearGroupCall();
 	void setGroupCallDefaultJoinAs(PeerId peerId);
 	[[nodiscard]] PeerId groupCallDefaultJoinAs() const;
