@@ -57,12 +57,22 @@ struct DocumentAdditionalData {
 
 };
 
+enum class StickerType : uchar {
+	Webp,
+	Tgs,
+	Webm,
+};
+
 struct StickerData : public DocumentAdditionalData {
-	Data::FileOrigin setOrigin() const;
+	[[nodiscard]] Data::FileOrigin setOrigin() const;
+	[[nodiscard]] bool isStatic() const;
+	[[nodiscard]] bool isLottie() const;
+	[[nodiscard]] bool isAnimated() const;
+	[[nodiscard]] bool isWebm() const;
 
-	bool animated = false;
 	QString alt;
 	StickerSetIdentifier set;
+	StickerType type = StickerType::Webp;
 };
 
 struct SongData : public DocumentAdditionalData {
