@@ -100,7 +100,7 @@ public:
 	// Returns text with link-start and link-end commands for service-color highlighting.
 	// Example: "[link1-start]You:[link1-end] [link1-start]Photo,[link1-end] caption text"
 	virtual ItemPreview toPreview(ToPreviewOptions way) const;
-	virtual QString notificationText() const = 0;
+	virtual TextWithEntities notificationText() const = 0;
 	virtual QString pinnedTextSubstring() const = 0;
 	virtual TextForMimeData clipboardText() const = 0;
 	virtual bool allowsForward() const;
@@ -161,7 +161,7 @@ public:
 	Image *replyPreview() const override;
 	bool replyPreviewLoaded() const override;
 	ItemPreview toPreview(ToPreviewOptions options) const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	bool allowsEditCaption() const override;
@@ -199,7 +199,7 @@ public:
 	Image *replyPreview() const override;
 	bool replyPreviewLoaded() const override;
 	ItemPreview toPreview(ToPreviewOptions options) const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	bool allowsEditCaption() const override;
@@ -234,7 +234,7 @@ public:
 	std::unique_ptr<Media> clone(not_null<HistoryItem*> parent) override;
 
 	const SharedContact *sharedContact() const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 
@@ -265,7 +265,7 @@ public:
 
 	Data::CloudImage *location() const override;
 	ItemPreview toPreview(ToPreviewOptions options) const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 
@@ -292,7 +292,7 @@ public:
 	std::unique_ptr<Media> clone(not_null<HistoryItem*> parent) override;
 
 	const Call *call() const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	bool allowsForward() const override;
@@ -331,7 +331,7 @@ public:
 	Image *replyPreview() const override;
 	bool replyPreviewLoaded() const override;
 	ItemPreview toPreview(ToPreviewOptions options) const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	bool allowsEdit() const override;
@@ -361,7 +361,7 @@ public:
 	bool hasReplyPreview() const override;
 	Image *replyPreview() const override;
 	bool replyPreviewLoaded() const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	QString errorTextForForward(not_null<PeerData*> peer) const override;
@@ -396,7 +396,7 @@ public:
 	bool hasReplyPreview() const override;
 	Image *replyPreview() const override;
 	bool replyPreviewLoaded() const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 
@@ -423,7 +423,7 @@ public:
 
 	PollData *poll() const override;
 
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	QString errorTextForForward(not_null<PeerData*> peer) const override;
@@ -450,7 +450,7 @@ public:
 	[[nodiscard]] int value() const;
 
 	bool allowsRevoke(TimeId now) const override;
-	QString notificationText() const override;
+	TextWithEntities notificationText() const override;
 	QString pinnedTextSubstring() const override;
 	TextForMimeData clipboardText() const override;
 	bool forceForwardedInfo() const override;
