@@ -32,6 +32,12 @@ void OpenWithPreparedFile(
 	Fn<void()> &&doneCallback);
 
 void PrepareProfilePhoto(
+	not_null<Ui::RpWidget*> parent,
+	not_null<Window::Controller*> controller,
+	Fn<void(QImage &&image)> &&doneCallback,
+	QImage &&image);
+
+void PrepareProfilePhotoFromFile(
 	not_null<Ui::RpWidget*> parent,
 	not_null<Window::Controller*> controller,
 	Fn<void(QImage &&image)> &&doneCallback);
