@@ -34,11 +34,11 @@ ItemSticker::ItemSticker(
 	}
 	const auto updateThumbnail = [=] {
 		const auto guard = gsl::finally([&] {
-			setAspectRatio(_pixmap.isNull()
-				? 1.0
-				: (_pixmap.height() / float64(_pixmap.width())));
+			if (_pixmap.isNull()) {
+				setAspectRatio(1.);
+			}
 		});
-		if (stickerData->animated) {
+		if (stickerData->isLottie()) {
 			_lottie.player = ChatHelpers::LottiePlayerFromDocument(
 				_mediaView.get(),
 				ChatHelpers::StickerLottieSize::MessageHistory,
@@ -54,16 +54,33 @@ ItemSticker::ItemSticker(
 				update();
 			}, _lottie.lifetime);
 			return true;
+		} else if (stickerData->isWebm()
+			&& !_document->dimensions.isEmpty()) {
+			const auto callback = [=](::Media::Clip::Notification) {
+				const auto size = _document->dimensions;
+				if (_webm && _webm->ready() && !_webm->started()) {
+					_webm->start({ .frame = size, .keepAlpha = true });
+				}
+				if (_webm && _webm->started()) {
+					updatePixmap(_webm->current(
+						{ .frame = size, .keepAlpha = true },
+						0));
+					_webm = nullptr;
+				}
+			};
+			_webm = ::Media::Clip::MakeReader(
+				_mediaView->owner()->location(),
+				_mediaView->bytes(),
+				callback);
+			return true;
 		}
 		const auto sticker = _mediaView->getStickerLarge();
 		if (!sticker) {
 			return false;
 		}
-		auto pixmap = sticker->pixNoCache(
-			sticker->width() * cIntRetinaFactor(),
-			sticker->height() * cIntRetinaFactor(),
-			Images::Option::Smooth);
-		pixmap.setDevicePixelRatio(cRetinaFactor());
+		const auto ratio = style::DevicePixelRatio();
+		auto pixmap = sticker->pixNoCache(sticker->size() * ratio);
+		pixmap.setDevicePixelRatio(ratio);
 		updatePixmap(std::move(pixmap));
 		return true;
 	};
@@ -85,6 +102,9 @@ void ItemSticker::updatePixmap(QPixmap &&pixmap) {
 	} else {
 		update();
 	}
+	if (!_pixmap.isNull()) {
+		setAspectRatio(_pixmap.height() / float64(_pixmap.width()));
+	}
 }
 
 void ItemSticker::paint(
