@@ -8,6 +8,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "export/view/export_view_top_bar.h"
 
 #include "export/view/export_view_content.h"
+#include "ui/text/text_utilities.h"
 #include "ui/widgets/continuous_sliders.h"
 #include "ui/widgets/labels.h"
 #include "ui/widgets/buttons.h"
@@ -39,13 +40,12 @@ void TopBar::updateData(Content &&content) {
 		return;
 	}
 	const auto &row = content.rows[0];
-	_info->setRichText(textcmdStartSemibold()
-		+ TextUtilities::Clean(tr::lng_export_progress_title(tr::now))
-		+ textcmdStopSemibold()
-		+ QString::fromUtf8(" \xe2\x80\x93 ")
-		+ TextUtilities::Clean(row.label)
-		+ ' '
-		+ textcmdLink(1, TextUtilities::Clean(row.info)));
+	_info->setMarkedText(
+		Ui::Text::Bold(tr::lng_export_progress_title(tr::now))
+			.append(" \xe2\x80\x93 ")
+			.append(row.label)
+			.append(' ')
+			.append(Ui::Text::PlainLink(row.info)));
 	_progress->setValue(row.progress);
 }
 
