@@ -219,7 +219,7 @@ TextWithEntities GenerateAdminChangeText(
 	return result;
 };
 
-QString GenerateBannedChangeText(
+QString GeneratePermissionsChangeText(
 		ChatRestrictionsInfo newRights,
 		ChatRestrictionsInfo prevRights) {
 	using Flag = ChatRestriction;
@@ -242,7 +242,7 @@ QString GenerateBannedChangeText(
 	return CollectChanges(phraseMap, prevRights.flags, newRights.flags);
 }
 
-TextWithEntities GenerateBannedChangeText(
+TextWithEntities GeneratePermissionsChangeText(
 		PeerId participantId,
 		const TextWithEntities &user,
 		ChatRestrictionsInfo newRights,
@@ -281,7 +281,7 @@ TextWithEntities GenerateBannedChangeText(
 		lt_until,
 		TextWithEntities { untilText },
 		Ui::Text::WithEntities);
-	const auto changes = GenerateBannedChangeText(newRights, prevRights);
+	const auto changes = GeneratePermissionsChangeText(newRights, prevRights);
 	if (!changes.isEmpty()) {
 		result.text.append('\n' + changes);
 	}
@@ -478,7 +478,13 @@ auto GenerateParticipantChangeText(
 				ChatAdminRightsInfo(),
 				oldRights);
 		} else if (oldParticipant && oldParticipant->type() == Type::Banned) {
-			return GenerateBannedChangeText(
+			return GeneratePermissionsChangeText(
+				participantId,
+				user,
+				ChatRestrictionsInfo(),
+				oldRestrictions);
+		} else if (oldParticipant && oldParticipant->type() == Type::Restricted && participant.type() == Type::Member) {
+			return GeneratePermissionsChangeText(
 				participantId,
 				user,
 				ChatRestrictionsInfo(),
@@ -517,7 +523,7 @@ auto GenerateParticipantChangeText(
 			const auto user = GenerateParticipantString(
 				&channel->session(),
 				peerId);
-			return GenerateBannedChangeText(
+			return GeneratePermissionsChangeText(
 				peerId,
 				user,
 				participant.restrictions(),
@@ -556,7 +562,7 @@ TextWithEntities GenerateDefaultBannedRightsChangeText(
 	auto result = TextWithEntities{
 		tr::lng_admin_log_changed_default_permissions(tr::now)
 	};
-	const auto changes = GenerateBannedChangeText(rights, oldRights);
+	const auto changes = GeneratePermissionsChangeText(rights, oldRights);
 	if (!changes.isEmpty()) {
 		result.text.append('\n' + changes);
 	}
@@ -669,7 +675,7 @@ void GenerateItems(
 
 	const auto fromName = from->name;
 	const auto fromLink = from->createOpenLink();
-	const auto fromLinkText = Ui::Text::Link(fromName, {});
+	const auto fromLinkText = Ui::Text::Link(fromName, QString());
 
 	const auto addSimpleServiceMessage = [&](
 			const TextWithEntities &text,
@@ -981,7 +987,7 @@ void GenerateItems(
 				lt_sticker_set,
 				Ui::Text::Link(
 					tr::lng_admin_log_changed_stickers_set(tr::now),
-					{}),
+					QString()),
 				Ui::Text::WithEntities);
 			const auto setLink = std::make_shared<LambdaClickHandler>([=](
 					ClickContext context) {
@@ -1066,7 +1072,7 @@ void GenerateItems(
 					lt_from,
 					fromLinkText,
 					lt_chat,
-					Ui::Text::Link(now->name, {}),
+					Ui::Text::Link(now->name, QString()),
 					Ui::Text::WithEntities);
 			const auto chatLink = std::make_shared<LambdaClickHandler>([=] {
 				Ui::showPeerHistory(now, ShowAtUnreadMsgId);
@@ -1190,7 +1196,7 @@ void GenerateItems(
 		const auto participantPeerLink = participantPeer->createOpenLink();
 		const auto participantPeerLinkText = Ui::Text::Link(
 			participantPeer->name,
-			{});
+			QString());
 		const auto text = (broadcast
 			? tr::lng_admin_log_muted_participant_channel
 			: tr::lng_admin_log_muted_participant)(
@@ -1209,7 +1215,7 @@ void GenerateItems(
 		const auto participantPeerLink = participantPeer->createOpenLink();
 		const auto participantPeerLinkText = Ui::Text::Link(
 			participantPeer->name,
-			{});
+			QString());
 		const auto text = (broadcast
 			? tr::lng_admin_log_unmuted_participant_channel
 			: tr::lng_admin_log_unmuted_participant)(
@@ -1313,7 +1319,7 @@ void GenerateItems(
 		const auto participantPeerLink = participantPeer->createOpenLink();
 		const auto participantPeerLinkText = Ui::Text::Link(
 			participantPeer->name,
-			{});
+			QString());
 		const auto volume = data.vparticipant().match([&](
 				const MTPDgroupCallParticipant &data) {
 			return data.vvolume().value_or(10000);
@@ -1389,7 +1395,7 @@ void GenerateItems(
 				lt_link,
 				linkText,
 				lt_user,
-				Ui::Text::Link(user->name, {}),
+				Ui::Text::Link(user->name, QString()),
 				Ui::Text::WithEntities),
 			data.vinvite(),
 			user->createOpenLink());
