@@ -97,7 +97,7 @@ using ItemPreview = HistoryView::ItemPreview;
 					return;
 				}
 			}
-			windows.front()->startOrJoinGroupCall(peer);
+			windows.front()->startOrJoinGroupCall(peer, {});
 		}
 	});
 }
@@ -143,7 +143,7 @@ void HistoryService::setMessageByAction(const MTPmessageAction &action) {
 				auto user = history()->owner().user(users[i].v);
 				result.links.push_back(user->createOpenLink());
 
-				auto linkText = Ui::Text::Link(user->name, QString());
+				auto linkText = Ui::Text::Link(user->name, 2 + i);
 				if (i == 0) {
 					result.text = linkText;
 				} else if (i + 1 == l) {
