@@ -8,6 +8,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/view/history_view_list_widget.h"
 
 #include "base/unixtime.h"
+#include "base/qt/qt_key_modifiers.h"
 #include "history/history_message.h"
 #include "history/history_item_components.h"
 #include "history/history_item_text.h"
@@ -34,6 +35,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/toast/toast.h"
 #include "ui/toasts/common_toasts.h"
 #include "ui/inactive_press.h"
+#include "ui/effects/message_sending_animation_controller.h"
 #include "ui/effects/path_shift_gradient.h"
 #include "ui/chat/chat_theme.h"
 #include "ui/chat/chat_style.h"
@@ -329,7 +331,9 @@ ListWidget::ListWidget(
 		itemRemoved(item);
 	}, lifetime());
 
-	subscribe(session().data().queryItemVisibility(), [this](const Data::Session::ItemVisibilityQuery &query) {
+	session().data().itemVisibilityQueries(
+	) | rpl::start_with_next([=](
+			const Data::Session::ItemVisibilityQuery &query) {
 		if (const auto view = viewForItem(query.item)) {
 			const auto top = itemTop(view);
 			if (top >= 0
@@ -338,7 +342,7 @@ ListWidget::ListWidget(
 				*query.isVisible = true;
 			}
 		}
-	});
+	}, lifetime());
 
 	using ChosenReaction = Reactions::Manager::Chosen;
 	_reactionsManager->chosen(
@@ -352,7 +356,7 @@ ListWidget::ListWidget(
 			return;
 		} else if (const auto view = viewForItem(item)) {
 			if (const auto top = itemTop(view); top >= 0) {
-				view->animateSendReaction({
+				view->animateReaction({
 					.emoji = reaction.emoji,
 					.flyIcon = reaction.icon,
 					.flyFrom = reaction.geometry.translated(0, -top),
@@ -792,6 +796,7 @@ void ListWidget::visibleTopBottomUpdated(
 		scrollDateHideByTimer();
 	}
 	_controller->floatPlayerAreaUpdated();
+	session().data().itemVisibilitiesUpdated();
 	_applyUpdatedScrollState.call();
 }
 
@@ -1554,6 +1559,7 @@ void ListWidget::resizeToWidth(int newWidth, int minHeight) {
 void ListWidget::startItemRevealAnimations() {
 	for (const auto &view : base::take(_itemRevealPending)) {
 		if (const auto height = view->height()) {
+			startMessageSendingAnimation(view->data());
 			if (!_itemRevealAnimations.contains(view)) {
 				auto &animation = _itemRevealAnimations[view];
 				animation.startHeight = height;
@@ -1572,6 +1578,30 @@ void ListWidget::startItemRevealAnimations() {
 	}
 }
 
+void ListWidget::startMessageSendingAnimation(
+		not_null<HistoryItem*> item) {
+	auto &sendingAnimation = controller()->sendingAnimation();
+	if (!sendingAnimation.hasLocalMessage(item->fullId().msg)
+		|| !sendingAnimation.checkExpectedType(item)) {
+		return;
+	}
+
+	auto globalEndTopLeft = rpl::merge(
+		session().data().newItemAdded() | rpl::to_empty,
+		geometryValue() | rpl::to_empty
+	) | rpl::map([=] {
+		const auto view = viewForItem(item);
+		const auto additional = !_visibleTop ? view->height() : 0;
+		return mapToGlobal(QPoint(0, itemTop(view) - additional));
+	});
+
+	sendingAnimation.startAnimation({
+		.globalEndTopLeft = std::move(globalEndTopLeft),
+		.view = [=] { return viewForItem(item); },
+		.paintContext = [=] { return preparePaintContext({}); },
+	});
+}
+
 void ListWidget::revealItemsCallback() {
 	auto revealHeight = 0;
 	for (auto i = begin(_itemRevealAnimations)
@@ -1706,6 +1736,17 @@ TextSelection ListWidget::itemRenderSelection(
 	return TextSelection();
 }
 
+Ui::ChatPaintContext ListWidget::preparePaintContext(
+		const QRect &clip) const {
+	return controller()->preparePaintContext({
+		.theme = _delegate->listChatTheme(),
+		.visibleAreaTop = _visibleTop,
+		.visibleAreaTopGlobal = mapToGlobal(QPoint(0, _visibleTop)).y(),
+		.visibleAreaWidth = width(),
+		.clip = clip,
+	});
+}
+
 void ListWidget::paintEvent(QPaintEvent *e) {
 	if (Ui::skipPaintEvent(this, e)) {
 		return;
@@ -1735,21 +1776,18 @@ void ListWidget::paintEvent(QPaintEvent *e) {
 		_reactionsManager->startEffectsCollection();
 
 		auto top = itemTop(from->get());
-		auto context = controller()->preparePaintContext({
-			.theme = _delegate->listChatTheme(),
-			.visibleAreaTop = _visibleTop,
-			.visibleAreaTopGlobal = mapToGlobal(QPoint(0, _visibleTop)).y(),
-			.visibleAreaWidth = width(),
-			.clip = clip,
-		}).translated(0, -top);
+		auto context = preparePaintContext(clip).translated(0, -top);
 		p.translate(0, top);
+		const auto &sendingAnimation = _controller->sendingAnimation();
 		for (auto i = from; i != to; ++i) {
 			const auto view = *i;
-			context.reactionEffects
-				= _reactionsManager->currentReactionEffect();
-			context.outbg = view->hasOutLayout();
-			context.selection = itemRenderSelection(view);
-			view->draw(p, context);
+			if (!sendingAnimation.hasAnimatedMessage(view->data())) {
+				context.reactionInfo
+					= _reactionsManager->currentReactionPaintInfo();
+				context.outbg = view->hasOutLayout();
+				context.selection = itemRenderSelection(view);
+				view->draw(p, context);
+			}
 			_reactionsManager->recordCurrentReactionEffect(
 				view->data()->fullId(),
 				QPoint(0, top));
@@ -1778,12 +1816,29 @@ void ListWidget::paintEvent(QPaintEvent *e) {
 						view->width(),
 						st::msgPhotoSize);
 				} else if (const auto info = view->data()->hiddenSenderInfo()) {
-					info->userpic.paint(
-						p,
-						st::historyPhotoLeft,
-						userpicTop,
-						view->width(),
-						st::msgPhotoSize);
+					if (info->customUserpic.empty()) {
+						info->emptyUserpic.paint(
+							p,
+							st::historyPhotoLeft,
+							userpicTop,
+							view->width(),
+							st::msgPhotoSize);
+					} else {
+						const auto painted = info->paintCustomUserpic(
+							p,
+							st::historyPhotoLeft,
+							userpicTop,
+							view->width(),
+							st::msgPhotoSize);
+						if (!painted) {
+							const auto itemId = view->data()->fullId();
+							auto &v = _sponsoredUserpics[itemId.msg];
+							if (!info->customUserpic.isCurrentView(v)) {
+								v = info->customUserpic.createView();
+								info->customUserpic.load(&session(), itemId);
+							}
+						}
+					}
 				} else {
 					Unexpected("Corrupt forwarded information in message.");
 				}
@@ -2664,6 +2719,9 @@ void ListWidget::mouseActionUpdate() {
 		} else {
 			inTextSelection = false;
 		}
+		if (base::IsAltPressed()) {
+			request.flags &= ~Ui::Text::StateRequest::Flag::LookupLink;
+		}
 
 		const auto dateHeight = st::msgServicePadding.bottom()
 			+ st::msgServiceFont->height
@@ -3177,7 +3235,10 @@ void ListWidget::setEmptyInfoWidget(base::unique_qptr<Ui::RpWidget> &&w) {
 	_emptyInfo = std::move(w);
 }
 
-ListWidget::~ListWidget() = default;
+ListWidget::~ListWidget() {
+	// Destroy child widgets first, because they may invoke leaveEvent-s.
+	_emptyInfo = nullptr;
+}
 
 void ConfirmDeleteSelectedItems(not_null<ListWidget*> widget) {
 	const auto items = widget->getSelectedItems();
