@@ -19,6 +19,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "history/view/history_view_group_call_bar.h" // UserpicInRow.
 #include "history/view/history_view_view_button.h" // ViewButton.
 #include "history/history.h"
+#include "boxes/share_box.h"
 #include "ui/effects/ripple_animation.h"
 #include "base/unixtime.h"
 #include "ui/chat/message_bubble.h"
@@ -459,7 +460,7 @@ QSize Message::performCountOptimalSize() {
 			forwarded->create(via);
 		}
 		if (reply) {
-			reply->updateName();
+			reply->updateName(item);
 		}
 
 		auto mediaDisplayed = false;
@@ -930,7 +931,7 @@ void Message::draw(Painter &p, const PaintContext &context) const {
 	}
 
 	if (const auto reply = displayedReply()) {
-		if (reply->isNameUpdated()) {
+		if (reply->isNameUpdated(message())) {
 			const_cast<Message*>(this)->setPendingResize();
 		}
 	}
@@ -1390,8 +1391,11 @@ bool Message::hasFromPhoto() const {
 	case Context::Pinned:
 	case Context::Replies: {
 		const auto item = message();
-		if (item->isPost()
-			|| item->isEmpty()
+		if (item->isPost()) {
+			return item->isSponsored()
+				&& item->history()->peer->isMegagroup();
+		}
+		if (item->isEmpty()
 			|| (context() == Context::Replies && item->isDiscussionPost())) {
 			return false;
 		} else if (delegate()->elementIsChatWide()) {
@@ -1586,7 +1590,12 @@ TextState Message::textState(
 	}
 
 	if (keyboard && item->isHistoryEntry()) {
-		auto keyboardTop = g.top() + g.height() + st::msgBotKbButton.margin;
+		const auto keyboardTop = g.top()
+			+ g.height()
+			+ st::msgBotKbButton.margin
+			+ ((_reactions && !reactionsInBubble)
+				? (st::mediaInBubbleSkip + _reactions->height())
+				: 0);
 		if (QRect(g.left(), keyboardTop, g.width(), keyboardHeight).contains(point)) {
 			result.link = keyboard->getLink(point - QPoint(g.left(), keyboardTop));
 			return result;
@@ -2625,7 +2634,7 @@ ClickHandlerPtr Message::rightActionLink() const {
 					Window::SectionShow::Way::Forward,
 					savedFromMsgId);
 			} else {
-				FastShareMessage(item);
+				FastShareMessage(controller, item);
 			}
 		}
 	});
@@ -2748,6 +2757,42 @@ TextSelection Message::unskipTextSelection(TextSelection selection) const {
 	return HistoryView::ShiftItemSelection(selection, message()->_text);
 }
 
+QRect Message::innerGeometry() const {
+	auto result = countGeometry();
+	if (!hasOutLayout()) {
+		const auto w = std::max(
+			(media() ? media()->resolveCustomInfoRightBottom().x() : 0),
+			result.width());
+		result.setWidth(std::min(
+			w + rightActionSize().value_or(QSize(0, 0)).width() * 2,
+			width()));
+	}
+	if (hasBubble()) {
+		result.translate(0, st::msgPadding.top() + st::mediaInBubbleSkip);
+
+		if (displayFromName()) {
+			// See paintFromName().
+			result.translate(0, st::msgNameFont->height);
+		}
+		// Skip displayForwardedFrom() until there are no animations for it.
+		if (displayedReply()) {
+			// See paintReplyInfo().
+			result.translate(
+				0,
+				st::msgReplyPadding.top()
+					+ st::msgReplyBarSize.height()
+					+ st::msgReplyPadding.bottom());
+		}
+		if (!displayFromName() && !displayForwardedFrom()) {
+			// See paintViaBotIdInfo().
+			if (message()->Has<HistoryMessageVia>()) {
+				result.translate(0, st::msgServiceNameFont->height);
+			}
+		}
+	}
+	return result;
+}
+
 QRect Message::countGeometry() const {
 	const auto commentsRoot = (context() == Context::Replies)
 		&& data()->isDiscussionPost();
