@@ -393,6 +393,10 @@ not_null<HistoryService*> Service::message() const {
 	return static_cast<HistoryService*>(data().get());
 }
 
+QRect Service::innerGeometry() const {
+	return countGeometry();
+}
+
 QRect Service::countGeometry() const {
 	auto result = QRect(0, 0, width(), height());
 	if (delegate()->elementIsChatWide()) {
