@@ -63,6 +63,12 @@ namespace {
 
 constexpr auto kEmojiInteractionSeenDuration = 3 * crl::time(1000);
 
+inline bool HasGroupCallMenu(const not_null<PeerData*> &peer) {
+	return !peer->groupCall()
+		&& ((peer->isChannel() && peer->asChannel()->amCreator())
+			|| (peer->isChat() && peer->asChat()->amCreator()));
+}
+
 } // namespace
 
 struct TopBarWidget::EmojiInteractionSeenAnimation {
@@ -107,7 +113,7 @@ TopBarWidget::TopBarWidget(
 	_call->setClickedCallback([=] { call(); });
 	_groupCall->setClickedCallback([=] { groupCall(); });
 	_search->setClickedCallback([=] { search(); });
-	_menuToggle->setClickedCallback([=] { showMenu(); });
+	_menuToggle->setClickedCallback([=] { showPeerMenu(); });
 	_infoToggle->setClickedCallback([=] { toggleInfoSection(); });
 	_back->addClickHandler([=] { backClicked(); });
 	_cancelChoose->setClickedCallback(
@@ -177,11 +183,6 @@ TopBarWidget::TopBarWidget(
 		}
 	}, lifetime());
 
-	session().serverConfig().phoneCallsEnabled.changes(
-	) | rpl::start_with_next([=] {
-		updateControlsVisibility();
-	}, lifetime());
-
 	rpl::combine(
 		Core::App().settings().thirdSectionInfoEnabledValue(),
 		Core::App().settings().tabbedReplacedWithInfoValue()
@@ -245,7 +246,11 @@ void TopBarWidget::call() {
 
 void TopBarWidget::groupCall() {
 	if (const auto peer = _activeChat.key.peer()) {
-		_controller->startOrJoinGroupCall(peer);
+		if (HasGroupCallMenu(peer)) {
+			showGroupCallMenu(peer);
+		} else {
+			_controller->startOrJoinGroupCall(peer, {});
+		}
 	}
 }
 
@@ -277,47 +282,97 @@ void TopBarWidget::setChooseForReportReason(
 		: style::cur_default);
 }
 
-void TopBarWidget::showMenu() {
+bool TopBarWidget::createMenu(not_null<Ui::IconButton*> button) {
 	if (!_activeChat.key || _menu) {
-		return;
+		return false;
 	}
 	_menu.create(parentWidget(), st::dropdownMenuWithIcons);
-	_menu->setHiddenCallback([weak = Ui::MakeWeak(this), menu = _menu.data()]{
+	_menu->setHiddenCallback([
+			weak = Ui::MakeWeak(this),
+			weakButton = Ui::MakeWeak(button),
+			menu = _menu.data()] {
 		menu->deleteLater();
 		if (weak && weak->_menu == menu) {
 			weak->_menu = nullptr;
-			weak->_menuToggle->setForceRippled(false);
+			if (weakButton) {
+				weakButton->setForceRippled(false);
+			}
 		}
 	});
-	_menu->setShowStartCallback(crl::guard(this, [this, menu = _menu.data()]{
+	_menu->setShowStartCallback(crl::guard(this, [=, menu = _menu.data()] {
 		if (_menu == menu) {
-			_menuToggle->setForceRippled(true);
+			button->setForceRippled(true);
 		}
 	}));
-	_menu->setHideStartCallback(crl::guard(this, [this, menu = _menu.data()]{
+	_menu->setHideStartCallback(crl::guard(this, [=, menu = _menu.data()] {
 		if (_menu == menu) {
-			_menuToggle->setForceRippled(false);
+			button->setForceRippled(false);
 		}
 	}));
-	_menuToggle->installEventFilter(_menu);
+	button->installEventFilter(_menu);
+	return true;
+}
+
+void TopBarWidget::showPeerMenu() {
+	const auto created = createMenu(_menuToggle);
+	if (!created) {
+		return;
+	}
 	const auto addAction = [&](
 			const QString &text,
 			Fn<void()> callback,
 			const style::icon *icon) {
 		return _menu->addAction(text, std::move(callback), icon);
 	};
-	Window::FillDialogsEntryMenu(
-		_controller,
-		_activeChat,
-		addAction);
+	Window::FillDialogsEntryMenu(_controller, _activeChat, addAction);
 	if (_menu->empty()) {
 		_menu.destroy();
 	} else {
-		_menu->moveToRight((parentWidget()->width() - width()) + st::topBarMenuPosition.x(), st::topBarMenuPosition.y());
+		_menu->moveToRight(
+			(parentWidget()->width() - width()) + st::topBarMenuPosition.x(),
+			st::topBarMenuPosition.y());
 		_menu->showAnimated(Ui::PanelAnimation::Origin::TopRight);
 	}
 }
 
+void TopBarWidget::showGroupCallMenu(not_null<PeerData*> peer) {
+	const auto created = createMenu(_groupCall);
+	if (!created) {
+		return;
+	}
+	const auto controller = _controller;
+	const auto callback = [=](Calls::StartGroupCallArgs &&args) {
+		controller->startOrJoinGroupCall(peer, std::move(args));
+	};
+	const auto livestream = !peer->isMegagroup() && peer->isChannel();
+	_menu->addAction(
+		livestream
+			? tr::lng_menu_start_group_call_channel(tr::now)
+			: tr::lng_menu_start_group_call(tr::now),
+		[=] { callback({}); },
+		&st::menuIconStartStream);
+	_menu->addAction(
+		livestream
+			? tr::lng_menu_start_group_call_scheduled_channel(tr::now)
+			: tr::lng_menu_start_group_call_scheduled(tr::now),
+		[=] { callback({ .scheduleNeeded = true }); },
+		&st::menuIconReschedule);
+	_menu->addAction(
+		livestream
+			? tr::lng_menu_start_group_call_with_channel(tr::now)
+			: tr::lng_menu_start_group_call_with(tr::now),
+		[=] { callback({ .rtmpNeeded = true }); },
+		&st::menuIconStartStreamWith);
+	_menu->moveToRight(
+		(parentWidget()->width() - width())
+			+ (width()
+				- _groupCall->x()
+				- _groupCall->width()
+				- st::topBarMenuGroupCallSkip),
+		st::topBarMenuPosition.y());
+	_menu->showAnimated(Ui::PanelAnimation::Origin::TopRight);
+}
+
 void TopBarWidget::toggleInfoSection() {
 	const auto isThreeColumn = _controller->adaptive().isThreeColumn();
 	if (isThreeColumn
@@ -403,6 +458,8 @@ void TopBarWidget::paintTopBar(Painter &p) {
 				return tr::lng_report_reason_child_abuse(tr::now);
 			case Reason::Pornography:
 				return tr::lng_report_reason_pornography(tr::now);
+			case Reason::Copyright:
+				return tr::lng_report_reason_copyright(tr::now);
 			}
 			Unexpected("reason in TopBarWidget::paintTopBar.");
 		}();
