@@ -57,6 +57,7 @@ public:
 	void updateControlsVisibility();
 	void finishAnimating();
 	void showSelected(SelectedState state);
+	[[nodiscard]] bool showSelectedState() const;
 	rpl::producer<bool> membersShowAreaActive() const {
 		return _membersShowAreaActive.events();
 	}
@@ -108,9 +109,12 @@ private:
 	void groupCall();
 	void startGroupCall(not_null<ChannelData*> megagroup, bool confirmed);
 	void search();
-	void showMenu();
+	void showPeerMenu();
+	void showGroupCallMenu(not_null<PeerData*> peer);
 	void toggleInfoSection();
 
+	[[nodiscard]] bool createMenu(not_null<Ui::IconButton*> button);
+
 	void handleEmojiInteractionSeen(const QString &emoticon);
 	bool paintSendAction(
 		Painter &p,
