@@ -148,6 +148,9 @@ QSize Contact::countOptimalSize() {
 	accumulate_max(maxWidth, tleft + _name.maxWidth() + tright);
 	accumulate_min(maxWidth, st::msgMaxWidth);
 	auto minHeight = st.padding.top() + st.thumbSize + st.padding.bottom();
+	if (_parent->bottomInfoIsWide()) {
+		minHeight += st::msgDateFont->height - st::msgDateDelta.y();
+	}
 	if (!isBubbleTop()) {
 		minHeight -= st::msgFileTopMinus;
 	}
