@@ -358,6 +358,9 @@ void Gif::draw(Painter &p, const PaintContext &context) const {
 			usex = width() - usew;
 		}
 	}
+	if (isUnwrapped()) {
+		accumulate_min(usew, painth);
+	}
 	if (rtl()) usex = width() - usex - usew;
 
 	QRect rthumb(style::rtlrect(usex + paintx, painty, usew, painth, width()));
@@ -381,7 +384,9 @@ void Gif::draw(Painter &p, const PaintContext &context) const {
 			| ((isRoundedInBubbleBottom() && _caption.isEmpty())
 				? (RectPart::BottomLeft | RectPart::BottomRight)
 				: RectPart::None));
-	if (streamed) {
+	const auto skipDrawingContent = context.skipDrawingParts
+		== PaintContext::SkipDrawingParts::Content;
+	if (streamed && !skipDrawingContent) {
 		auto paused = autoPaused;
 		if (isRound) {
 			if (activeRoundStreamed()) {
@@ -415,9 +420,21 @@ void Gif::draw(Painter &p, const PaintContext &context) const {
 				activeOwnPlaying->frozenFrame = QImage();
 				activeOwnPlaying->frozenStatusText = QString();
 			}
-			p.drawImage(rthumb, streamed->frame(request));
-			if (!paused) {
-				streamed->markFrameShown();
+
+			const auto frame = streamed->frameWithInfo(request);
+			const auto playOnce = sticker
+				&& !Core::App().settings().loopAnimatedStickers();
+			const auto switchToNext = !playOnce
+				|| (frame.index != 0)
+				|| !_stickerOncePlayed;
+			p.drawImage(rthumb, frame.image);
+			if (!paused
+				&& switchToNext
+				&& streamed->markFrameShown()
+				&& playOnce
+				&& !_stickerOncePlayed) {
+				_stickerOncePlayed = true;
+				_parent->delegate()->elementStartStickerLoop(_parent);
 			}
 		}
 
@@ -443,7 +460,7 @@ void Gif::draw(Painter &p, const PaintContext &context) const {
 				p.setOpacity(1.);
 			}
 		}
-	} else {
+	} else if (!skipDrawingContent) {
 		ensureDataMediaCreated();
 		const auto size = QSize(_thumbw, _thumbh);
 		const auto args = Images::PrepareArgs{
@@ -579,9 +596,12 @@ void Gif::draw(Painter &p, const PaintContext &context) const {
 		sti->historyVideoMessageMute.paintInCenter(p, muteRect);
 	}
 
-	if (!unwrapped) {
+	const auto skipDrawingSurrounding = context.skipDrawingParts
+		== PaintContext::SkipDrawingParts::Surrounding;
+
+	if (!unwrapped && !skipDrawingSurrounding) {
 		drawCornerStatus(p, context, QPoint());
-	} else {
+	} else if (!skipDrawingSurrounding) {
 		if (isRound) {
 			const auto mediaUnread = item->hasUnreadMediaFlag();
 			auto statusW = st::normalFont->width(_statusText) + 2 * st::msgDateImgPadding.x();
@@ -646,7 +666,7 @@ void Gif::draw(Painter &p, const PaintContext &context) const {
 	if (!unwrapped && !_caption.isEmpty()) {
 		p.setPen(stm->historyTextFg);
 		_caption.draw(p, st::msgPadding.left(), painty + painth + st::mediaCaptionSkip, captionw, style::al_left, 0, -1, context.selection);
-	} else if (!inWebPage) {
+	} else if (!inWebPage && !skipDrawingSurrounding) {
 		auto fullRight = paintx + usex + usew;
 		auto fullBottom = painty + painth;
 		auto maxRight = _parent->width() - st::msgMargin.left();
@@ -827,6 +847,9 @@ TextState Gif::textState(QPoint point, StateRequest request) const {
 			usex = width() - usew;
 		}
 	}
+	if (isUnwrapped()) {
+		accumulate_min(usew, painth);
+	}
 	if (rtl()) usex = width() - usex - usew;
 
 	if (via || reply || forwarded) {
@@ -1653,6 +1676,7 @@ bool Gif::needInfoDisplay() const {
 	return _parent->data()->isSending()
 		|| _data->uploading()
 		|| _parent->isUnderCursor()
+		|| (_data->sticker() && _parent->rightActionSize())
 		// Don't show the GIF badge if this message has text.
 		|| (!_parent->hasBubble() && _parent->isLastAndSelfMessage());
 }
