@@ -11,6 +11,10 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 class HistoryItem;
 
+namespace Api {
+struct WhoReadList;
+} // namespace Api
+
 namespace Window {
 class SessionController;
 } // namespace Window
@@ -24,6 +28,7 @@ namespace HistoryView {
 object_ptr<Ui::BoxContent> ReactionsListBox(
 	not_null<Window::SessionController*> window,
 	not_null<HistoryItem*> item,
-	QString selected);
+	QString selected,
+	std::shared_ptr<Api::WhoReadList> whoReadIds = nullptr);
 
 } // namespace HistoryView
