@@ -30,6 +30,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/boxes/confirm_box.h"
 #include "main/main_session.h"
 #include "mtproto/mtproto_config.h"
+#include "data/data_download_manager.h"
 #include "data/data_session.h"
 #include "data/data_changes.h"
 #include "data/data_user.h"
@@ -37,6 +38,8 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "lang/lang_keys.h"
 #include "styles/style_info.h"
 #include "styles/style_profile.h"
+#include "styles/style_menu_icons.h"
+#include "styles/style_layers.h"
 
 namespace Info {
 namespace {
@@ -198,8 +201,10 @@ Key WrapWidget::key() const {
 
 Dialogs::RowDescriptor WrapWidget::activeChat() const {
 	if (const auto peer = key().peer()) {
-		return Dialogs::RowDescriptor(peer->owner().history(peer), FullMsgId());
-	} else if (key().settingsSelf() || key().poll()) {
+		return Dialogs::RowDescriptor(
+			peer->owner().history(peer),
+			FullMsgId());
+	} else if (key().settingsSelf() || key().isDownloads() || key().poll()) {
 		return Dialogs::RowDescriptor();
 	}
 	Unexpected("Owner in WrapWidget::activeChat().");
@@ -341,9 +346,9 @@ void WrapWidget::createTopBar() {
 		_controller.get(),
 		TopBarStyle(wrapValue),
 		std::move(selectedItems));
-	_topBar->cancelSelectionRequests(
-	) | rpl::start_with_next([this] {
-		_content->cancelSelection();
+	_topBar->selectionActionRequests(
+	) | rpl::start_with_next([=](SelectionAction action) {
+		_content->selectionAction(action);
 	}, _topBar->lifetime());
 
 	_topBar->setTitle(TitleValue(
@@ -389,14 +394,33 @@ void WrapWidget::createTopBar() {
 		&& (wrapValue != Wrap::Side || hasStackHistory())) {
 		addTopBarMenuButton();
 		addProfileCallsButton();
-//		addProfileNotificationsButton();
 	} else if (section.type() == Section::Type::Settings
 		&& (section.settingsType() == Section::SettingsType::Main
 			|| section.settingsType() == Section::SettingsType::Chat)) {
 		addTopBarMenuButton();
-	} else if (section.type() == Section::Type::Settings
-		&& section.settingsType() == Section::SettingsType::Information) {
-		addContentSaveButton();
+	} else if (section.type() == Section::Type::Downloads) {
+		auto &manager = Core::App().downloadManager();
+		rpl::merge(
+			rpl::single(false),
+			manager.loadingListChanges() | rpl::map_to(false),
+			manager.loadedAdded() | rpl::map_to(true),
+			manager.loadedRemoved() | rpl::map_to(false)
+		) | rpl::start_with_next([=, &manager](bool definitelyHas) {
+			const auto has = [&] {
+				for ([[maybe_unused]] const auto id : manager.loadingList()) {
+					return true;
+				}
+				for ([[maybe_unused]] const auto id : manager.loadedList()) {
+					return true;
+				}
+				return false;
+			};
+			if (!definitelyHas && !has()) {
+				_topBarMenuToggle = nullptr;
+			} else if (!_topBarMenuToggle) {
+				addTopBarMenuButton();
+			}
+		}, _topBar->lifetime());
 	}
 
 	_topBar->lower();
@@ -406,18 +430,8 @@ void WrapWidget::createTopBar() {
 }
 
 void WrapWidget::checkBeforeClose(Fn<void()> close) {
-	const auto confirmed = [=] {
-		Ui::hideLayer();
-		close();
-	};
-	if (_controller->canSaveChangesNow()) {
-		Ui::show(Box<Ui::ConfirmBox>(
-			tr::lng_settings_close_sure(tr::now),
-			tr::lng_close(tr::now),
-			confirmed));
-	} else {
-		confirmed();
-	}
+	Ui::hideLayer();
+	close();
 }
 
 void WrapWidget::addTopBarMenuButton() {
@@ -434,25 +448,8 @@ void WrapWidget::addTopBarMenuButton() {
 	});
 }
 
-void WrapWidget::addContentSaveButton() {
-	Expects(_topBar != nullptr);
-
-	_topBar->addButtonWithVisibility(
-		base::make_unique_q<Ui::IconButton>(
-			_topBar,
-			(wrap() == Wrap::Layer
-				? st::infoLayerTopBarSave
-				: st::infoTopBarSave)),
-		_controller->canSaveChanges()
-	)->addClickHandler([=] {
-		_content->saveChanges(crl::guard(_content.data(), [=] {
-			_controller->showBackFromStack();
-		}));
-	});
-}
-
 bool WrapWidget::closeByOutsideClick() const {
-	return !_controller->canSaveChangesNow();
+	return true;
 }
 
 void WrapWidget::addProfileCallsButton() {
@@ -460,9 +457,7 @@ void WrapWidget::addProfileCallsButton() {
 
 	const auto peer = key().peer();
 	const auto user = peer ? peer->asUser() : nullptr;
-	if (!user
-		|| user->sharedMediaInfo()
-		|| !user->session().serverConfig().phoneCallsEnabled.current()) {
+	if (!user || user->sharedMediaInfo()) {
 		return;
 	}
 
@@ -490,46 +485,15 @@ void WrapWidget::addProfileCallsButton() {
 	}
 }
 
-void WrapWidget::addProfileNotificationsButton() {
-	Expects(_topBar != nullptr);
-
-	const auto peer = key().peer();
-	if (!peer) {
-		return;
-	}
-	auto notifications = _topBar->addButton(
-		base::make_unique_q<Ui::IconButton>(
-			_topBar,
-			(wrap() == Wrap::Layer
-				? st::infoLayerTopBarNotifications
-				: st::infoTopBarNotifications)));
-	notifications->addClickHandler([=] {
-		const auto muteForSeconds = peer->owner().notifyIsMuted(peer)
-			? 0
-			: Data::NotifySettings::kDefaultMutePeriod;
-		peer->owner().updateNotifySettings(peer, muteForSeconds);
-	});
-	Profile::NotificationsEnabledValue(
-		peer
-	) | rpl::start_with_next([notifications](bool enabled) {
-		const auto iconOverride = enabled
-			? &st::infoNotificationsActive
-			: nullptr;
-		const auto rippleOverride = enabled
-			? &st::lightButtonBgOver
-			: nullptr;
-		notifications->setIconOverride(iconOverride, iconOverride);
-		notifications->setRippleColorOverride(rippleOverride);
-	}, notifications->lifetime());
-}
-
 void WrapWidget::showTopBarMenu() {
 	if (_topBarMenu) {
 		_topBarMenu->hideAnimated(
 			Ui::InnerDropdown::HideOption::IgnoreShow);
 		return;
 	}
-	_topBarMenu = base::make_unique_q<Ui::DropdownMenu>(this);
+	_topBarMenu = base::make_unique_q<Ui::DropdownMenu>(
+		this,
+		st::dropdownMenuWithIcons);
 
 	_topBarMenu->setHiddenCallback([this] {
 		InvokeQueued(this, [this] { _topBarMenu = nullptr; });
@@ -551,10 +515,16 @@ void WrapWidget::showTopBarMenu() {
 
 	const auto addAction = [=](
 			const QString &text,
-			Fn<void()> callback) {
-		return _topBarMenu->addAction(text, std::move(callback));
+			Fn<void()> callback,
+			const style::icon *icon) {
+		return _topBarMenu->addAction(text, std::move(callback), icon);
 	};
-	if (const auto peer = key().peer()) {
+	if (key().isDownloads()) {
+		addAction(
+			tr::lng_context_delete_all_files(tr::now),
+			[=] { deleteAllDownloads(); },
+			&st::menuIconDelete);
+	} else if (const auto peer = key().peer()) {
 		Window::FillDialogsEntryMenu(
 			_controller->parentController(),
 			Dialogs::EntryState{
@@ -584,6 +554,24 @@ void WrapWidget::showTopBarMenu() {
 	_topBarMenu->showAnimated(Ui::PanelAnimation::Origin::TopRight);
 }
 
+void WrapWidget::deleteAllDownloads() {
+	auto &manager = Core::App().downloadManager();
+	const auto phrase = tr::lng_downloads_delete_sure_all(tr::now);
+	const auto added = manager.loadedHasNonCloudFile()
+		? QString()
+		: tr::lng_downloads_delete_in_cloud(tr::now);
+	const auto deleteSure = [=, &manager](Fn<void()> close) {
+		Ui::PostponeCall(this, close);
+		manager.deleteAll();
+	};
+	_controller->parentController()->show(Ui::MakeConfirmBox({
+		.text = phrase + (added.isEmpty() ? QString() : "\n\n" + added),
+		.confirmed = deleteSure,
+		.confirmText = tr::lng_box_delete(tr::now),
+		.confirmStyle = &st::attentionBoxButton,
+	}));
+}
+
 bool WrapWidget::requireTopBarSearch() const {
 	if (!_controller->searchFieldController()) {
 		return false;
@@ -917,7 +905,9 @@ void WrapWidget::showNewContent(
 			&& newContent->hasTopBarShadow();
 		animationParams.oldContentCache = grabForShowAnimation(
 			animationParams);
-		animationParams.withFade = (wrap() == Wrap::Layer);
+		const auto layer = (wrap() == Wrap::Layer);
+		animationParams.withFade = layer;
+		animationParams.topSkip = layer ? st::boxRadius : 0;
 	}
 	if (saveToStack) {
 		auto item = StackItem();
@@ -930,13 +920,19 @@ void WrapWidget::showNewContent(
 		_historyStack.clear();
 	}
 
-	_controller = std::move(newController);
-	if (newContent) {
-		setupTop();
-		showContent(std::move(newContent));
-	} else {
-		showNewContent(memento);
+	{
+		// Let old controller outlive old content widget.
+		const auto oldController = std::exchange(
+			_controller,
+			std::move(newController));
+		if (newContent) {
+			setupTop();
+			showContent(std::move(newContent));
+		} else {
+			showNewContent(memento);
+		}
 	}
+
 	if (animationParams) {
 		if (Ui::InFocusChain(this)) {
 			setFocus();
