@@ -17,13 +17,13 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "ui/wrap/slide_wrap.h"
 #include "ui/wrap/vertical_layout.h"
 #include "ui/widgets/buttons.h"
+#include "settings/settings_common.h"
 #include "window/window_session_controller.h"
 #include "data/data_channel.h"
 #include "data/data_user.h"
 #include "styles/style_info.h"
 
-namespace Info {
-namespace Media {
+namespace Info::Media {
 
 using Type = Storage::SharedMediaType;
 
@@ -54,7 +54,7 @@ inline auto AddCountedButton(
 		Ui::MultiSlideTracker &tracker) {
 	using namespace rpl::mappers;
 
-	using Button = Ui::SettingsButton;
+	using namespace ::Settings;
 	auto forked = std::move(count)
 		| start_spawning(parent->lifetime());
 	auto text = rpl::duplicate(
@@ -66,7 +66,7 @@ inline auto AddCountedButton(
 	});
 	auto button = parent->add(object_ptr<Ui::SlideWrap<Button>>(
 		parent,
-		object_ptr<Button>(
+		CreateButton(
 			parent,
 			std::move(text),
 			st::infoSharedMediaButton))
@@ -117,5 +117,4 @@ inline auto AddCommonGroupsButton(
 	return result;
 };
 
-} // namespace Media
-} // namespace Info
+} // namespace Info::Media
