@@ -18,7 +18,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "data/data_channel.h"
 #include "data/data_chat.h"
 #include "data/data_user.h"
-#include "boxes/confirm_box.h"
+#include "ui/boxes/confirm_box.h"
 #include "window/window_session_controller.h"
 #include "styles/style_info.h"
 #include "data/data_peer_values.h"
@@ -37,7 +37,7 @@ void MemberListRow::setType(Type type) {
 	_type = type;
 }
 
-QSize MemberListRow::actionSize() const {
+QSize MemberListRow::rightActionSize() const {
 	return canRemove()
 		? QRect(
 			QPoint(),
@@ -46,7 +46,7 @@ QSize MemberListRow::actionSize() const {
 		: QSize();
 }
 
-void MemberListRow::paintAction(
+void MemberListRow::rightActionPaint(
 		Painter &p,
 		int x,
 		int y,
