@@ -130,8 +130,12 @@ void Instance::check() {
 }
 
 Instance::~Instance() {
-	InvokeQueued(_inner.get(), [copy = base::take(_inner)] {
-	});
+	// Send _inner to it's thread for destruction.
+	if (const auto context = _inner.get()) {
+		InvokeQueued(context, [copy = base::take(_inner)]{});
+	}
+
+	// And wait for it to finish.
 	_thread.quit();
 	_thread.wait();
 }
@@ -147,7 +151,7 @@ struct Instance::Inner::Private {
 	AVIOContext *ioContext = nullptr;
 	AVFormatContext *fmtContext = nullptr;
 	AVStream *stream = nullptr;
-	AVCodec *codec = nullptr;
+	const AVCodec *codec = nullptr;
 	AVCodecContext *codecContext = nullptr;
 	bool opened = false;
 	bool processing = false;
@@ -305,7 +309,7 @@ void Instance::Inner::start(Fn<void(Update)> updated, Fn<void()> error) {
 	av_opt_set_int(d->codecContext, "refcounted_frames", 1, 0);
 
 	d->codecContext->sample_fmt = AV_SAMPLE_FMT_FLTP;
-	d->codecContext->bit_rate = 64000;
+	d->codecContext->bit_rate = 32000;
 	d->codecContext->channel_layout = AV_CH_LAYOUT_MONO;
 	d->codecContext->sample_rate = kCaptureFrequency;
 	d->codecContext->channels = 1;
