@@ -10,7 +10,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "media/clip/media_clip_ffmpeg.h"
 #include "media/clip/media_clip_check_streaming.h"
 #include "core/file_location.h"
-#include "base/openssl_help.h"
+#include "base/random.h"
 #include "base/invoke_queued.h"
 #include "logs.h"
 
@@ -35,51 +35,59 @@ constexpr auto kClipThreadsCount = 8;
 constexpr auto kAverageGifSize = 320 * 240;
 constexpr auto kWaitBeforeGifPause = crl::time(200);
 
-QVector<QThread*> threads;
-QVector<Manager*> managers;
-
 QImage PrepareFrameImage(const FrameRequest &request, const QImage &original, bool hasAlpha, QImage &cache) {
-	auto needResize = (original.width() != request.framew) || (original.height() != request.frameh);
-	auto needOuterFill = (request.outerw != request.framew) || (request.outerh != request.frameh);
-	auto needRounding = (request.radius != ImageRoundRadius::None);
+	const auto needResize = (original.size() != request.frame);
+	const auto needOuterFill = request.outer.isValid() && (request.outer != request.frame);
+	const auto needRounding = (request.radius != ImageRoundRadius::None);
 	if (!needResize && !needOuterFill && !hasAlpha && !needRounding) {
 		return original;
 	}
 
-	auto factor = request.factor;
-	auto needNewCache = (cache.width() != request.outerw || cache.height() != request.outerh);
+	const auto factor = request.factor;
+	const auto size = request.outer.isValid() ? request.outer : request.frame;
+	const auto needNewCache = (cache.size() != size);
 	if (needNewCache) {
-		cache = QImage(request.outerw, request.outerh, QImage::Format_ARGB32_Premultiplied);
+		cache = QImage(size, QImage::Format_ARGB32_Premultiplied);
 		cache.setDevicePixelRatio(factor);
 	}
+	if (hasAlpha && request.keepAlpha) {
+		cache.fill(Qt::transparent);
+	}
 	{
 		Painter p(&cache);
-		if (needNewCache) {
-			if (request.framew < request.outerw) {
-				p.fillRect(0, 0, (request.outerw - request.framew) / (2 * factor), cache.height() / factor, st::imageBg);
-				p.fillRect((request.outerw - request.framew) / (2 * factor) + (request.framew / factor), 0, (cache.width() / factor) - ((request.outerw - request.framew) / (2 * factor) + (request.framew / factor)), cache.height() / factor, st::imageBg);
+		const auto framew = request.frame.width();
+		const auto outerw = size.width();
+		const auto frameh = request.frame.height();
+		const auto outerh = size.height();
+		if (needNewCache && (!hasAlpha || !request.keepAlpha)) {
+			if (framew < outerw) {
+				p.fillRect(0, 0, (outerw - framew) / (2 * factor), cache.height() / factor, st::imageBg);
+				p.fillRect((outerw - framew) / (2 * factor) + (framew / factor), 0, (cache.width() / factor) - ((outerw - framew) / (2 * factor) + (framew / factor)), cache.height() / factor, st::imageBg);
 			}
-			if (request.frameh < request.outerh) {
-				p.fillRect(qMax(0, (request.outerw - request.framew) / (2 * factor)), 0, qMin(cache.width(), request.framew) / factor, (request.outerh - request.frameh) / (2 * factor), st::imageBg);
-				p.fillRect(qMax(0, (request.outerw - request.framew) / (2 * factor)), (request.outerh - request.frameh) / (2 * factor) + (request.frameh / factor), qMin(cache.width(), request.framew) / factor, (cache.height() / factor) - ((request.outerh - request.frameh) / (2 * factor) + (request.frameh / factor)), st::imageBg);
+			if (frameh < outerh) {
+				p.fillRect(qMax(0, (outerw - framew) / (2 * factor)), 0, qMin(cache.width(), framew) / factor, (outerh - frameh) / (2 * factor), st::imageBg);
+				p.fillRect(qMax(0, (outerw - framew) / (2 * factor)), (outerh - frameh) / (2 * factor) + (frameh / factor), qMin(cache.width(), framew) / factor, (cache.height() / factor) - ((outerh - frameh) / (2 * factor) + (frameh / factor)), st::imageBg);
 			}
 		}
-		if (hasAlpha) {
-			p.fillRect(qMax(0, (request.outerw - request.framew) / (2 * factor)), qMax(0, (request.outerh - request.frameh) / (2 * factor)), qMin(cache.width(), request.framew) / factor, qMin(cache.height(), request.frameh) / factor, st::imageBgTransparent);
+		if (hasAlpha && !request.keepAlpha) {
+			p.fillRect(qMax(0, (outerw - framew) / (2 * factor)), qMax(0, (outerh - frameh) / (2 * factor)), qMin(cache.width(), framew) / factor, qMin(cache.height(), frameh) / factor, st::imageBgTransparent);
 		}
-		auto position = QPoint((request.outerw - request.framew) / (2 * factor), (request.outerh - request.frameh) / (2 * factor));
+		const auto position = QPoint((outerw - framew) / (2 * factor), (outerh - frameh) / (2 * factor));
 		if (needResize) {
 			PainterHighQualityEnabler hq(p);
 
-			auto dst = QRect(position, QSize(request.framew / factor, request.frameh / factor));
-			auto src = QRect(0, 0, original.width(), original.height());
+			const auto dst = QRect(position, QSize(framew / factor, frameh / factor));
+			const auto src = QRect(0, 0, original.width(), original.height());
 			p.drawImage(dst, original, src, Qt::ColorOnly);
 		} else {
 			p.drawImage(position, original);
 		}
 	}
 	if (needRounding) {
-		Images::prepareRound(cache, request.radius, request.corners);
+		cache = Images::Round(
+			std::move(cache),
+			request.radius,
+			request.corners);
 	}
 	return cache;
 }
@@ -90,6 +98,81 @@ QPixmap PrepareFrame(const FrameRequest &request, const QImage &original, bool h
 
 } // namespace
 
+enum class ProcessResult {
+	Error,
+	Started,
+	Finished,
+	Paused,
+	Repaint,
+	CopyFrame,
+	Wait,
+};
+
+class Manager final : public QObject {
+public:
+	explicit Manager(not_null<QThread*> thread);
+	~Manager();
+
+	int loadLevel() const {
+		return _loadLevel;
+	}
+	void append(Reader *reader, const Core::FileLocation &location, const QByteArray &data);
+	void start(Reader *reader);
+	void update(Reader *reader);
+	void stop(Reader *reader);
+	bool carries(Reader *reader) const;
+
+private:
+	void process();
+	void finish();
+	void callback(Reader *reader, Notification notification);
+	void clear();
+
+	QAtomicInt _loadLevel;
+	using ReaderPointers = QMap<Reader*, QAtomicInt>;
+	ReaderPointers _readerPointers;
+	mutable QMutex _readerPointersMutex;
+
+	ReaderPointers::const_iterator constUnsafeFindReaderPointer(ReaderPrivate *reader) const;
+	ReaderPointers::iterator unsafeFindReaderPointer(ReaderPrivate *reader);
+
+	bool handleProcessResult(ReaderPrivate *reader, ProcessResult result, crl::time ms);
+
+	enum ResultHandleState {
+		ResultHandleRemove,
+		ResultHandleStop,
+		ResultHandleContinue,
+	};
+	ResultHandleState handleResult(ReaderPrivate *reader, ProcessResult result, crl::time ms);
+
+	using Readers = QMap<ReaderPrivate*, crl::time>;
+	Readers _readers;
+
+	QTimer _timer;
+	QThread *_processingInThread = nullptr;
+	bool _needReProcess = false;
+
+};
+
+namespace {
+
+struct Worker {
+	Worker() : manager(&thread) {
+		thread.start();
+	}
+	~Worker() {
+		thread.quit();
+		thread.wait();
+	}
+
+	QThread thread;
+	Manager manager;
+};
+
+std::vector<std::unique_ptr<Worker>>  Workers;
+
+} // namespace
+
 Reader::Reader(
 	const Core::FileLocation &location,
 	const QByteArray &data,
@@ -109,33 +192,31 @@ Reader::Reader(const QByteArray &data, Callback &&callback)
 }
 
 void Reader::init(const Core::FileLocation &location, const QByteArray &data) {
-	if (threads.size() < kClipThreadsCount) {
-		_threadIndex = threads.size();
-		threads.push_back(new QThread());
-		managers.push_back(new Manager(threads.back()));
-		threads.back()->start();
+	if (Workers.size() < kClipThreadsCount) {
+		_threadIndex = Workers.size();
+		Workers.push_back(std::make_unique<Worker>());
 	} else {
-		_threadIndex = int32(openssl::RandomValue<uint32>() % threads.size());
-		int32 loadLevel = 0x7FFFFFFF;
-		for (int32 i = 0, l = threads.size(); i < l; ++i) {
-			int32 level = managers.at(i)->loadLevel();
+		_threadIndex = base::RandomIndex(Workers.size());
+		auto loadLevel = 0x7FFFFFFF;
+		for (int i = 0, l = int(Workers.size()); i < l; ++i) {
+			const auto level = Workers[i]->manager.loadLevel();
 			if (level < loadLevel) {
 				_threadIndex = i;
 				loadLevel = level;
 			}
 		}
 	}
-	managers.at(_threadIndex)->append(this, location, data);
+	Workers[_threadIndex]->manager.append(this, location, data);
 }
 
 Reader::Frame *Reader::frameToShow(int32 *index) const { // 0 means not ready
 	int step = _step.loadAcquire(), i;
-	if (step == WaitingForDimensionsStep) {
+	if (step == kWaitingForDimensionsStep) {
 		if (index) *index = 0;
 		return nullptr;
-	} else if (step == WaitingForRequestStep) {
+	} else if (step == kWaitingForRequestStep) {
 		i = 0;
-	} else if (step == WaitingForFirstFrameStep) {
+	} else if (step == kWaitingForFirstFrameStep) {
 		i = 0;
 	} else {
 		i = (step / 2) % 3;
@@ -146,12 +227,12 @@ Reader::Frame *Reader::frameToShow(int32 *index) const { // 0 means not ready
 
 Reader::Frame *Reader::frameToWrite(int32 *index) const { // 0 means not ready
 	int32 step = _step.loadAcquire(), i;
-	if (step == WaitingForDimensionsStep) {
+	if (step == kWaitingForDimensionsStep) {
 		i = 0;
-	} else if (step == WaitingForRequestStep) {
+	} else if (step == kWaitingForRequestStep) {
 		if (index) *index = 0;
 		return nullptr;
-	} else if (step == WaitingForFirstFrameStep) {
+	} else if (step == kWaitingForFirstFrameStep) {
 		i = 0;
 	} else {
 		i = ((step + 2) / 2) % 3;
@@ -162,7 +243,9 @@ Reader::Frame *Reader::frameToWrite(int32 *index) const { // 0 means not ready
 
 Reader::Frame *Reader::frameToWriteNext(bool checkNotWriting, int32 *index) const {
 	int32 step = _step.loadAcquire(), i;
-	if (step == WaitingForDimensionsStep || step == WaitingForRequestStep || (checkNotWriting && (step % 2))) {
+	if (step == kWaitingForDimensionsStep
+		|| step == kWaitingForRequestStep
+		|| (checkNotWriting && (step % 2))) {
 		if (index) *index = 0;
 		return nullptr;
 	}
@@ -173,10 +256,10 @@ Reader::Frame *Reader::frameToWriteNext(bool checkNotWriting, int32 *index) cons
 
 void Reader::moveToNextShow() const {
 	int32 step = _step.loadAcquire();
-	if (step == WaitingForDimensionsStep) {
-	} else if (step == WaitingForRequestStep) {
-		_step.storeRelease(WaitingForFirstFrameStep);
-	} else if (step == WaitingForFirstFrameStep) {
+	if (step == kWaitingForDimensionsStep) {
+	} else if (step == kWaitingForRequestStep) {
+		_step.storeRelease(kWaitingForFirstFrameStep);
+	} else if (step == kWaitingForFirstFrameStep) {
 	} else if (!(step % 2)) {
 		_step.storeRelease(step + 1);
 	}
@@ -184,10 +267,10 @@ void Reader::moveToNextShow() const {
 
 void Reader::moveToNextWrite() const {
 	int32 step = _step.loadAcquire();
-	if (step == WaitingForDimensionsStep) {
-		_step.storeRelease(WaitingForRequestStep);
-	} else if (step == WaitingForRequestStep) {
-	} else if (step == WaitingForFirstFrameStep) {
+	if (step == kWaitingForDimensionsStep) {
+		_step.storeRelease(kWaitingForRequestStep);
+	} else if (step == kWaitingForRequestStep) {
+	} else if (step == kWaitingForFirstFrameStep) {
 		_step.storeRelease(0);
 
 		// Force paint the first frame so moveToNextShow() is called.
@@ -197,67 +280,79 @@ void Reader::moveToNextWrite() const {
 	}
 }
 
-void Reader::callback(Reader *reader, qint32 threadIndex, qint32 notification) {
+void Reader::SafeCallback(
+		Reader *reader,
+		int threadIndex,
+		Notification notification) {
 	// Check if reader is not deleted already
-	if (managers.size() > threadIndex && managers.at(threadIndex)->carries(reader) && reader->_callback) {
+	if (Workers.size() > threadIndex
+		&& Workers[threadIndex]->manager.carries(reader)
+		&& reader->_callback) {
 		reader->_callback(Notification(notification));
 	}
 }
 
-void Reader::start(int32 framew, int32 frameh, int32 outerw, int32 outerh, ImageRoundRadius radius, RectParts corners) {
-	if (managers.size() <= _threadIndex) error();
-	if (_state == State::Error) return;
-
-	if (_step.loadAcquire() == WaitingForRequestStep) {
-		int factor = style::DevicePixelRatio();
-		FrameRequest request;
-		request.factor = factor;
-		request.framew = framew * factor;
-		request.frameh = frameh * factor;
-		request.outerw = outerw * factor;
-		request.outerh = outerh * factor;
-		request.radius = radius;
-		request.corners = corners;
-		_frames[0].request = _frames[1].request = _frames[2].request = request;
-		moveToNextShow();
-		managers.at(_threadIndex)->start(this);
+void Reader::start(FrameRequest request) {
+	if (Workers.size() <= _threadIndex) {
+		error();
 	}
+	if (_state == State::Error
+		|| (_step.loadAcquire() != kWaitingForRequestStep)) {
+		return;
+	}
+	const auto factor = style::DevicePixelRatio();
+	request.factor = factor;
+	request.frame *= factor;
+	if (request.outer.isValid()) {
+		request.outer *= factor;
+	}
+	_frames[0].request = _frames[1].request = _frames[2].request = request;
+	moveToNextShow();
+	Workers[_threadIndex]->manager.start(this);
 }
 
-QPixmap Reader::current(int32 framew, int32 frameh, int32 outerw, int32 outerh, ImageRoundRadius radius, RectParts corners, crl::time ms) {
-	Expects(outerw > 0);
-	Expects(outerh > 0);
+QPixmap Reader::current(FrameRequest request, crl::time now) {
+	Expects(!(request.outer.isValid()
+		? request.outer
+		: request.frame).isEmpty());
 
-	auto frame = frameToShow();
+	const auto frame = frameToShow();
 	Assert(frame != nullptr);
 
-	auto shouldBePaused = !ms;
+	const auto shouldBePaused = !now;
 	if (!shouldBePaused) {
 		frame->displayed.storeRelease(1);
 		if (_autoPausedGif.loadAcquire()) {
 			_autoPausedGif.storeRelease(0);
-			if (managers.size() <= _threadIndex) error();
-			if (_state != State::Error) {
-				managers.at(_threadIndex)->update(this);
+			if (Workers.size() <= _threadIndex) {
+				error();
+			} else if (_state != State::Error) {
+				Workers[_threadIndex]->manager.update(this);
 			}
 		}
 	} else {
 		frame->displayed.storeRelease(-1);
 	}
 
-	auto factor = style::DevicePixelRatio();
-	if (frame->pix.width() == outerw * factor
-		&& frame->pix.height() == outerh * factor
-		&& frame->request.radius == radius
-		&& frame->request.corners == corners) {
+	const auto factor = style::DevicePixelRatio();
+	request.factor = factor;
+	request.frame *= factor;
+	if (request.outer.isValid()) {
+		request.outer *= factor;
+	}
+	const auto size = request.outer.isValid()
+		? request.outer
+		: request.frame;
+	Assert(frame->request.radius == request.radius
+		&& frame->request.corners == request.corners
+		&& frame->request.keepAlpha == request.keepAlpha);
+	if (frame->pix.size() == size) {
 		moveToNextShow();
 		return frame->pix;
 	}
 
-	frame->request.framew = framew * factor;
-	frame->request.frameh = frameh * factor;
-	frame->request.outerw = outerw * factor;
-	frame->request.outerh = outerh * factor;
+	frame->request.frame = request.frame;
+	frame->request.outer = request.outer;
 
 	QImage cacheForResize;
 	frame->original.setDevicePixelRatio(factor);
@@ -269,18 +364,21 @@ QPixmap Reader::current(int32 framew, int32 frameh, int32 outerw, int32 outerh,
 
 	moveToNextShow();
 
-	if (managers.size() <= _threadIndex) error();
-	if (_state != State::Error) {
-		managers.at(_threadIndex)->update(this);
+	if (Workers.size() <= _threadIndex) {
+		error();
+	} else if (_state != State::Error) {
+		Workers[_threadIndex]->manager.update(this);
 	}
 
 	return frame->pix;
 }
 
 bool Reader::ready() const {
-	if (_width && _height) return true;
+	if (_width && _height) {
+		return true;
+	}
 
-	auto frame = frameToShow();
+	const auto frame = frameToShow();
 	if (frame) {
 		_width = frame->original.width();
 		_height = frame->original.height();
@@ -290,7 +388,7 @@ bool Reader::ready() const {
 }
 
 crl::time Reader::getPositionMs() const {
-	if (auto frame = frameToShow()) {
+	if (const auto frame = frameToShow()) {
 		return frame->positionMs;
 	}
 	return 0;
@@ -301,11 +399,13 @@ crl::time Reader::getDurationMs() const {
 }
 
 void Reader::pauseResumeVideo() {
-	if (managers.size() <= _threadIndex) error();
+	if (Workers.size() <= _threadIndex) {
+		error();
+	}
 	if (_state == State::Error) return;
 
 	_videoPauseRequest.storeRelease(1 - _videoPauseRequest.loadAcquire());
-	managers.at(_threadIndex)->start(this);
+	Workers[_threadIndex]->manager.start(this);
 }
 
 bool Reader::videoPaused() const {
@@ -325,9 +425,11 @@ State Reader::state() const {
 }
 
 void Reader::stop() {
-	if (managers.size() <= _threadIndex) error();
+	if (Workers.size() <= _threadIndex) {
+		error();
+	}
 	if (_state != State::Error) {
-		managers.at(_threadIndex)->stop(this);
+		Workers[_threadIndex]->manager.stop(this);
 		_width = _height = 0;
 	}
 }
@@ -453,7 +555,7 @@ public:
 	bool renderFrame() {
 		Expects(_request.valid());
 
-		if (!_implementation->renderFrame(frame()->original, frame()->alpha, QSize(_request.framew, _request.frameh))) {
+		if (!_implementation->renderFrame(frame()->original, frame()->alpha, _request.frame)) {
 			return false;
 		}
 		frame()->original.setDevicePixelRatio(_request.factor);
@@ -566,7 +668,7 @@ private:
 
 };
 
-Manager::Manager(QThread *thread) {
+Manager::Manager(not_null<QThread*> thread) {
 	moveToThread(thread);
 	connect(thread, &QThread::started, this, [=] { process(); });
 	connect(thread, &QThread::finished, this, [=] { finish(); });
@@ -610,23 +712,29 @@ bool Manager::carries(Reader *reader) const {
 	return _readerPointers.contains(reader);
 }
 
-Manager::ReaderPointers::iterator Manager::unsafeFindReaderPointer(ReaderPrivate *reader) {
-	ReaderPointers::iterator it = _readerPointers.find(reader->_interface);
+auto Manager::unsafeFindReaderPointer(ReaderPrivate *reader)
+-> ReaderPointers::iterator {
+	const auto it = _readerPointers.find(reader->_interface);
 
 	// could be a new reader which was realloced in the same address
-	return (it == _readerPointers.cend() || it.key()->_private == reader) ? it : _readerPointers.end();
+	return (it == _readerPointers.cend() || it.key()->_private == reader)
+		? it
+		: _readerPointers.end();
 }
 
-Manager::ReaderPointers::const_iterator Manager::constUnsafeFindReaderPointer(ReaderPrivate *reader) const {
-	ReaderPointers::const_iterator it = _readerPointers.constFind(reader->_interface);
+auto Manager::constUnsafeFindReaderPointer(ReaderPrivate *reader) const
+-> ReaderPointers::const_iterator {
+	const auto it = _readerPointers.constFind(reader->_interface);
 
 	// could be a new reader which was realloced in the same address
-	return (it == _readerPointers.cend() || it.key()->_private == reader) ? it : _readerPointers.cend();
+	return (it == _readerPointers.cend() || it.key()->_private == reader)
+		? it
+		: _readerPointers.cend();
 }
 
 void Manager::callback(Reader *reader, Notification notification) {
 	crl::on_main([=, threadIndex = reader->threadIndex()] {
-		Reader::callback(reader, threadIndex, notification);
+		Reader::SafeCallback(reader, threadIndex, notification);
 	});
 }
 
@@ -636,14 +744,14 @@ bool Manager::handleProcessResult(ReaderPrivate *reader, ProcessResult result, c
 	if (result == ProcessResult::Error) {
 		if (it != _readerPointers.cend()) {
 			it.key()->error();
-			callback(it.key(), NotificationReinit);
+			callback(it.key(), Notification::Reinit);
 			_readerPointers.erase(it);
 		}
 		return false;
 	} else if (result == ProcessResult::Finished) {
 		if (it != _readerPointers.cend()) {
 			it.key()->finished();
-			callback(it.key(), NotificationReinit);
+			callback(it.key(), Notification::Reinit);
 		}
 		return false;
 	}
@@ -679,14 +787,14 @@ bool Manager::handleProcessResult(ReaderPrivate *reader, ProcessResult result, c
 		if (result == ProcessResult::Started) {
 			reader->startedAt(ms);
 			it.key()->moveToNextWrite();
-			callback(it.key(), NotificationReinit);
+			callback(it.key(), Notification::Reinit);
 		}
 	} else if (result == ProcessResult::Paused) {
 		it.key()->moveToNextWrite();
-		callback(it.key(), NotificationReinit);
+		callback(it.key(), Notification::Reinit);
 	} else if (result == ProcessResult::Repaint) {
 		it.key()->moveToNextWrite();
-		callback(it.key(), NotificationRepaint);
+		callback(it.key(), Notification::Repaint);
 	}
 	return true;
 }
@@ -842,6 +950,7 @@ Ui::PreparedFileInformation::Video PrepareForSending(const QString &fname, const
 		auto durationMs = reader->durationMs();
 		if (durationMs > 0) {
 			result.isGifv = reader->isGifv();
+			result.isWebmSticker = reader->isWebmSticker();
 			// Use first video frame as a thumbnail.
 			// All other apps and server do that way.
 			//if (!result.isGifv) {
@@ -854,13 +963,8 @@ Ui::PreparedFileInformation::Video PrepareForSending(const QString &fname, const
 			auto readResult = reader->readFramesTill(-1, crl::now());
 			auto readFrame = (readResult == internal::ReaderImplementation::ReadResult::Success);
 			if (readFrame && reader->renderFrame(result.thumbnail, hasAlpha, QSize())) {
-				if (hasAlpha) {
-					auto cacheForResize = QImage();
-					auto request = FrameRequest();
-					request.framew = request.outerw = result.thumbnail.width();
-					request.frameh = request.outerh = result.thumbnail.height();
-					request.factor = 1;
-					result.thumbnail = PrepareFrameImage(request, result.thumbnail, hasAlpha, cacheForResize);
+				if (hasAlpha && !result.isWebmSticker) {
+					result.thumbnail = Images::Opaque(std::move(result.thumbnail));
 				}
 				result.duration = static_cast<int>(durationMs / 1000);
 			}
@@ -874,17 +978,7 @@ Ui::PreparedFileInformation::Video PrepareForSending(const QString &fname, const
 }
 
 void Finish() {
-	if (!threads.isEmpty()) {
-		for (int32 i = 0, l = threads.size(); i < l; ++i) {
-			threads.at(i)->quit();
-			DEBUG_LOG(("Waiting for clipThread to finish: %1").arg(i));
-			threads.at(i)->wait();
-			delete managers.at(i);
-			delete threads.at(i);
-		}
-		threads.clear();
-		managers.clear();
-	}
+	Workers.clear();
 }
 
 Reader *const ReaderPointer::BadPointer = reinterpret_cast<Reader*>(1);
