@@ -7,6 +7,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 */
 #pragma once
 
+#include "base/observer.h"
 #include "data/data_audio_msg_id.h"
 #include "data/data_shared_media.h"
 
@@ -42,6 +43,8 @@ class PowerSaveBlocker;
 namespace Media {
 namespace Player {
 
+extern const char kOptionDisableAutoplayNext[];
+
 enum class RepeatMode {
 	None,
 	One,
@@ -165,8 +168,6 @@ public:
 
 	[[nodiscard]] bool pauseGifByRoundVideo() const;
 
-	void documentLoadProgress(DocumentData *document);
-
 private:
 	using SharedMediaType = Storage::SharedMediaType;
 	using SliceKey = SparseIdsMergedSlice::Key;
@@ -293,7 +294,10 @@ private:
 	void requestRoundVideoResize() const;
 	void requestRoundVideoRepaint() const;
 
-	void setHistory(not_null<Data*> data, History *history);
+	void setHistory(
+		not_null<Data*> data,
+		History *history,
+		Main::Session *sessionFallback = nullptr);
 	void setSession(not_null<Data*> data, Main::Session *session);
 
 	Data _songData;
