@@ -8,95 +8,65 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "mtproto/mtproto_concurrent_sender.h"
 
 #include "mtproto/mtp_instance.h"
-#include "mtproto/mtproto_rpc_sender.h"
+#include "mtproto/mtproto_response.h"
 #include "mtproto/facade.h"
 
 namespace MTP {
 
-class ConcurrentSender::RPCDoneHandler : public RPCAbstractDoneHandler {
+class ConcurrentSender::HandlerMaker final {
 public:
-	RPCDoneHandler(
+	static DoneHandler MakeDone(
 		not_null<ConcurrentSender*> sender,
 		Fn<void(FnMut<void()>)> runner);
-
-	bool operator()(
-		mtpRequestId requestId,
-		const mtpPrime *from,
-		const mtpPrime *end) override;
-
-private:
-	base::weak_ptr<ConcurrentSender> _weak;
-	Fn<void(FnMut<void()>)> _runner;
-
-};
-
-class ConcurrentSender::RPCFailHandler : public RPCAbstractFailHandler {
-public:
-	RPCFailHandler(
+	static FailHandler MakeFail(
 		not_null<ConcurrentSender*> sender,
 		Fn<void(FnMut<void()>)> runner,
 		FailSkipPolicy skipPolicy);
-
-	bool operator()(
-		mtpRequestId requestId,
-		const RPCError &error) override;
-
-private:
-	base::weak_ptr<ConcurrentSender> _weak;
-	Fn<void(FnMut<void()>)> _runner;
-	FailSkipPolicy _skipPolicy = FailSkipPolicy::Simple;
-
 };
 
-ConcurrentSender::RPCDoneHandler::RPCDoneHandler(
-	not_null<ConcurrentSender*> sender,
-	Fn<void(FnMut<void()>)> runner)
-: _weak(sender)
-, _runner(std::move(runner)) {
+DoneHandler ConcurrentSender::HandlerMaker::MakeDone(
+		not_null<ConcurrentSender*> sender,
+		Fn<void(FnMut<void()>)> runner) {
+	return [
+		weak = base::make_weak(sender.get()),
+		runner = std::move(runner)
+	](const Response &response) mutable {
+		runner([=]() mutable {
+			if (const auto strong = weak.get()) {
+				strong->senderRequestDone(
+					response.requestId,
+					bytes::make_span(response.reply));
+			}
+		});
+		return true;
+	};
 }
 
-bool ConcurrentSender::RPCDoneHandler::operator()(
-		mtpRequestId requestId,
-		const mtpPrime *from,
-		const mtpPrime *end) {
-	auto response = gsl::make_span(
-		from,
-		end - from);
-	_runner([=, weak = _weak, moved = bytes::make_vector(response)]() mutable {
-		if (const auto strong = weak.get()) {
-			strong->senderRequestDone(requestId, std::move(moved));
+FailHandler ConcurrentSender::HandlerMaker::MakeFail(
+		not_null<ConcurrentSender*> sender,
+		Fn<void(FnMut<void()>)> runner,
+		FailSkipPolicy skipPolicy) {
+	return [
+		weak = base::make_weak(sender.get()),
+		runner = std::move(runner),
+		skipPolicy
+	](const Error &error, const Response &response) mutable {
+		if (skipPolicy == FailSkipPolicy::Simple) {
+			if (IsDefaultHandledError(error)) {
+				return false;
+			}
+		} else if (skipPolicy == FailSkipPolicy::HandleFlood) {
+			if (IsDefaultHandledError(error) && !IsFloodError(error)) {
+				return false;
+			}
 		}
-	});
-	return true;
-}
-
-ConcurrentSender::RPCFailHandler::RPCFailHandler(
-	not_null<ConcurrentSender*> sender,
-	Fn<void(FnMut<void()>)> runner,
-	FailSkipPolicy skipPolicy)
-: _weak(sender)
-, _runner(std::move(runner))
-, _skipPolicy(skipPolicy) {
-}
-
-bool ConcurrentSender::RPCFailHandler::operator()(
-		mtpRequestId requestId,
-		const RPCError &error) {
-	if (_skipPolicy == FailSkipPolicy::Simple) {
-		if (MTP::isDefaultHandledError(error)) {
-			return false;
-		}
-	} else if (_skipPolicy == FailSkipPolicy::HandleFlood) {
-		if (MTP::isDefaultHandledError(error) && !MTP::isFloodError(error)) {
-			return false;
-		}
-	}
-	_runner([=, weak = _weak, error = error]() mutable {
-		if (const auto strong = weak.get()) {
-			strong->senderRequestFail(requestId, std::move(error));
-		}
-	});
-	return true;
+		runner([=, requestId = response.requestId]() mutable {
+			if (const auto strong = weak.get()) {
+				strong->senderRequestFail(requestId, error);
+			}
+		});
+		return true;
+	};
 }
 
 template <typename Method>
@@ -147,8 +117,8 @@ mtpRequestId ConcurrentSender::RequestBuilder::send() {
 	_sender->with_instance([
 		=,
 		request = std::move(_serialized),
-		done = std::make_shared<RPCDoneHandler>(_sender, _sender->_runner),
-		fail = std::make_shared<RPCFailHandler>(
+		done = HandlerMaker::MakeDone(_sender, _sender->_runner),
+		fail = HandlerMaker::MakeFail(
 			_sender,
 			_sender->_runner,
 			_failSkipPolicy)
@@ -156,7 +126,7 @@ mtpRequestId ConcurrentSender::RequestBuilder::send() {
 		instance->sendSerialized(
 			requestId,
 			std::move(request),
-			RPCResponseHandler(std::move(done), std::move(fail)),
+			ResponseHandler{ std::move(done), std::move(fail) },
 			dcId,
 			msCanWait,
 			afterRequestId);
@@ -189,7 +159,7 @@ void ConcurrentSender::senderRequestDone(
 		if (!handlers->done(requestId, result)) {
 			handlers->fail(
 				requestId,
-				RPCError::Local(
+				Error::Local(
 					"RESPONSE_PARSE_FAILED",
 					"ConcurrentSender::senderRequestDone"));
 		}
@@ -198,9 +168,9 @@ void ConcurrentSender::senderRequestDone(
 
 void ConcurrentSender::senderRequestFail(
 		mtpRequestId requestId,
-		RPCError &&error) {
+		const Error &error) {
 	if (auto handlers = _requests.take(requestId)) {
-		handlers->fail(requestId, std::move(error));
+		handlers->fail(requestId, error);
 	}
 }
 
