@@ -358,7 +358,7 @@ void Photo::setPixFrom(not_null<Image*> image) {
 	const auto size = _width * cIntRetinaFactor();
 	auto img = image->original();
 	if (!_goodLoaded) {
-		img = Images::prepareBlur(std::move(img));
+		img = Images::Blur(std::move(img));
 	}
 	if (img.width() == img.height()) {
 		if (img.width() != size) {
@@ -457,7 +457,7 @@ void Video::paint(Painter &p, const QRect &clip, TextSelection selection, const
 			? good->original()
 			: thumbnail
 			? thumbnail->original()
-			: Images::prepareBlur(blurred->original());
+			: Images::Blur(blurred->original());
 		if (img.width() == img.height()) {
 			if (img.width() != size) {
 				img = img.scaled(size, size, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
@@ -691,9 +691,11 @@ void Voice::paint(Painter &p, const QRect &clip, TextSelection selection, const
 
 		p.setPen(Qt::NoPen);
 		if (thumbnail || blurred) {
-			const auto thumb = thumbnail
-				? thumbnail->pixCircled(inner.width(), inner.height())
-				: blurred->pixBlurredCircled(inner.width(), inner.height());
+			const auto options = Images::Option::RoundCircle
+				| (blurred ? Images::Option::Blur : Images::Option());
+			const auto thumb = (thumbnail ? thumbnail : blurred)->pix(
+				inner.size(),
+				{ .options = options });
 			p.drawPixmap(inner.topLeft(), thumb);
 		} else if (_data->hasThumbnail()) {
 			PainterHighQualityEnabler hq(p);
@@ -918,11 +920,11 @@ bool Voice::updateStatusText() {
 Document::Document(
 	not_null<Delegate*> delegate,
 	not_null<HistoryItem*> parent,
-	not_null<DocumentData*> document,
+	DocumentFields fields,
 	const style::OverviewFileLayout &st)
 : RadialProgressItem(delegate, parent)
-, _data(document)
-, _msgl(goToMessageClickHandler(parent))
+, _data(fields.document)
+, _msgl(parent->isHistoryEntry() ? goToMessageClickHandler(parent) : nullptr)
 , _namel(std::make_shared<DocumentOpenClickHandler>(
 	_data,
 	crl::guard(this, [=](FullMsgId id) {
@@ -931,19 +933,28 @@ Document::Document(
 	parent->fullId()))
 , _st(st)
 , _generic(::Layout::DocumentGenericPreview::Create(_data))
-, _date(langDateTime(base::unixtime::parse(_data->date)))
+, _forceFileLayout(fields.forceFileLayout)
+, _date(langDateTime(base::unixtime::parse(fields.dateOverride
+	? fields.dateOverride
+	: _data->date)))
 , _ext(_generic.ext)
 , _datew(st::normalFont->width(_date)) {
 	_name.setMarkedText(
 		st::defaultTextStyle,
-		Ui::Text::FormatSongNameFor(_data).textWithEntities(),
+		(!_forceFileLayout
+			? Ui::Text::FormatSongNameFor(_data).textWithEntities()
+			: Ui::Text::FormatDownloadsName(_data)),
 		_documentNameOptions);
 
 	AddComponents(Info::Bit());
 
 	setDocumentLinks(_data);
 
-	_status.update(Ui::FileStatusSizeReady, _data->size, _data->isSong() ? _data->song()->duration : -1, 0);
+	_status.update(
+		Ui::FileStatusSizeReady,
+		_data->size,
+		songLayout() ? _data->song()->duration : -1,
+		0);
 
 	if (withThumb()) {
 		_data->loadThumbnail(parent->fullId());
@@ -974,7 +985,7 @@ bool Document::downloadInCorner() const {
 
 void Document::initDimensions() {
 	_maxw = _st.maxWidth;
-	if (_data->isSong()) {
+	if (songLayout()) {
 		_minh = _st.songPadding.top() + _st.songThumbSize + _st.songPadding.bottom();
 	} else {
 		_minh = _st.filePadding.top() + _st.fileThumbSize + _st.filePadding.bottom() + st::lineWidth;
@@ -1004,7 +1015,7 @@ void Document::paint(Painter &p, const QRect &clip, TextSelection selection, con
 	int32 nameleft = 0, nametop = 0, nameright = 0, statustop = 0, datetop = -1;
 	const auto wthumb = withThumb();
 
-	const auto isSong = _data->isSong();
+	const auto isSong = songLayout();
 	if (isSong) {
 		nameleft = _st.songPadding.left() + _st.songThumbSize + _st.songPadding.right();
 		nameright = _st.songPadding.left();
@@ -1088,7 +1099,7 @@ void Document::paint(Painter &p, const QRect &clip, TextSelection selection, con
 		datetop = st::linksBorder + _st.fileDateTop;
 
 		QRect border(style::rtlrect(nameleft, 0, _width - nameleft, st::linksBorder, _width));
-		if (!context->isAfterDate && clip.intersects(border)) {
+		if (!context->skipBorder && clip.intersects(border)) {
 			p.fillRect(clip.intersected(border), st::linksBorderFg);
 		}
 
@@ -1101,12 +1112,18 @@ void Document::paint(Painter &p, const QRect &clip, TextSelection selection, con
 				if (thumbnail || blurred) {
 					if (_thumb.isNull() || (thumbnail && !_thumbLoaded)) {
 						_thumbLoaded = (thumbnail != nullptr);
-						auto options = Images::Option::Smooth
-							| (_thumbLoaded
-								? Images::Option::None
-								: Images::Option::Blurred);
+						const auto options = _thumbLoaded
+							? Images::Option()
+							: Images::Option::Blur;
 						const auto image = thumbnail ? thumbnail : blurred;
-						_thumb = image->pixNoCache(_thumbw * cIntRetinaFactor(), 0, options, _st.fileThumbSize, _st.fileThumbSize);
+						_thumb = image->pixNoCache(
+							_thumbw * style::DevicePixelRatio(),
+							{
+								.options = options,
+								.outer = QSize(
+									_st.fileThumbSize,
+									_st.fileThumbSize),
+							});
 					}
 					p.drawPixmap(rthumb.topLeft(), _thumb);
 				} else {
@@ -1179,7 +1196,9 @@ void Document::paint(Painter &p, const QRect &clip, TextSelection selection, con
 		p.drawTextLeft(nameleft, statustop, _width, _status.text());
 	}
 	if (datetop >= 0 && clip.intersects(style::rtlrect(nameleft, datetop, _datew, st::normalFont->height, _width))) {
-		p.setFont(ClickHandler::showAsActive(_msgl) ? st::normalFont->underline() : st::normalFont);
+		p.setFont((_msgl && ClickHandler::showAsActive(_msgl))
+			? st::normalFont->underline()
+			: st::normalFont);
 		p.setPen(st::mediaInFg);
 		p.drawTextLeft(nameleft, datetop, _width, _date, _datew);
 	}
@@ -1256,7 +1275,7 @@ TextState Document::getState(
 	ensureDataMediaCreated();
 	const auto loaded = dataLoaded();
 
-	if (_data->isSong()) {
+	if (songLayout()) {
 		const auto nameleft = _st.songPadding.left() + _st.songThumbSize + _st.songPadding.right();
 		const auto nameright = _st.songPadding.left();
 		const auto namewidth = std::min(
@@ -1356,6 +1375,10 @@ const style::RoundCheckbox &Document::checkboxStyle() const {
 	return st::overviewSmallCheck;
 }
 
+bool Document::songLayout() const {
+	return !_forceFileLayout && _data->isSong();
+}
+
 void Document::ensureDataMediaCreated() const {
 	if (_dataMedia) {
 		return;
@@ -1384,13 +1407,13 @@ bool Document::dataLoaded() const {
 }
 
 bool Document::iconAnimated() const {
-	return _data->isSong()
+	return songLayout()
 		|| !dataLoaded()
 		|| (_radial && _radial->animating());
 }
 
 bool Document::withThumb() const {
-	return !_data->isSong()
+	return !songLayout()
 		&& _data->hasThumbnail()
 		&& !Data::IsExecutableName(_data->filename());
 }
@@ -1411,7 +1434,8 @@ bool Document::updateStatusText() {
 		statusSize = Ui::FileStatusSizeReady;
 	}
 
-	if (_data->isSong()) {
+	const auto isSong = songLayout();
+	if (isSong) {
 		const auto state = Media::Player::instance()->getState(AudioMsgId::Type::Song);
 		if (state.id == AudioMsgId(_data, parent()->fullId(), state.id.externalPlayId()) && !Media::Player::IsStoppedOrStopping(state.state)) {
 			statusSize = -1 - (state.position / state.frequency);
@@ -1424,7 +1448,11 @@ bool Document::updateStatusText() {
 	}
 
 	if (statusSize != _status.size()) {
-		_status.update(statusSize, _data->size, _data->isSong() ? _data->song()->duration : -1, realDuration);
+		_status.update(
+			statusSize,
+			_data->size,
+			isSong ? _data->song()->duration : -1,
+			realDuration);
 	}
 	return showPause;
 }
@@ -1653,7 +1681,7 @@ void Link::paint(Painter &p, const QRect &clip, TextSelection selection, const P
 	}
 
 	QRect border(style::rtlrect(left, 0, w, st::linksBorder, _width));
-	if (!context->isAfterDate && clip.intersects(border)) {
+	if (!context->skipBorder && clip.intersects(border)) {
 		p.fillRect(clip.intersected(border), st::linksBorderFg);
 	}
 
@@ -1668,20 +1696,26 @@ void Link::validateThumbnail() {
 	if (!_thumbnail.isNull() && !_thumbnailBlurred) {
 		return;
 	}
+	const auto size = QSize(_pixw, _pixh);
+	const auto outer = QSize(st::linksPhotoSize, st::linksPhotoSize);
 	if (_page && _page->photo) {
 		using Data::PhotoSize;
 		ensurePhotoMediaCreated();
+		const auto args = Images::PrepareArgs{
+			.options = Images::Option::RoundSmall,
+			.outer = outer,
+		};
 		if (const auto thumbnail = _photoMedia->image(PhotoSize::Thumbnail)) {
-			_thumbnail = thumbnail->pixSingle(_pixw, _pixh, st::linksPhotoSize, st::linksPhotoSize, ImageRoundRadius::Small);
+			_thumbnail = thumbnail->pixSingle(size, args);
 			_thumbnailBlurred = false;
 		} else if (const auto large = _photoMedia->image(PhotoSize::Large)) {
-			_thumbnail = large->pixSingle(_pixw, _pixh, st::linksPhotoSize, st::linksPhotoSize, ImageRoundRadius::Small);
+			_thumbnail = large->pixSingle(size, args);
 			_thumbnailBlurred = false;
 		} else if (const auto small = _photoMedia->image(PhotoSize::Small)) {
-			_thumbnail = small->pixSingle(_pixw, _pixh, st::linksPhotoSize, st::linksPhotoSize, ImageRoundRadius::Small);
+			_thumbnail = small->pixSingle(size, args);
 			_thumbnailBlurred = false;
 		} else if (const auto blurred = _photoMedia->thumbnailInline()) {
-			_thumbnail = blurred->pixBlurredSingle(_pixw, _pixh, st::linksPhotoSize, st::linksPhotoSize, ImageRoundRadius::Small);
+			_thumbnail = blurred->pixSingle(size, args.blurred());
 			return;
 		} else {
 			return;
@@ -1690,14 +1724,17 @@ void Link::validateThumbnail() {
 		delegate()->unregisterHeavyItem(this);
 	} else if (_page && _page->document && _page->document->hasThumbnail()) {
 		ensureDocumentMediaCreated();
-		const auto roundRadius = _page->document->isVideoMessage()
-			? ImageRoundRadius::Ellipse
-			: ImageRoundRadius::Small;
+		const auto args = Images::PrepareArgs{
+			.options = (_page->document->isVideoMessage()
+				? Images::Option::RoundCircle
+				: Images::Option::RoundSmall),
+			.outer = outer,
+		};
 		if (const auto thumbnail = _documentMedia->thumbnail()) {
-			_thumbnail = thumbnail->pixSingle(_pixw, _pixh, st::linksPhotoSize, st::linksPhotoSize, roundRadius);
+			_thumbnail = thumbnail->pixSingle(size, args);
 			_thumbnailBlurred = false;
 		} else if (const auto blurred = _documentMedia->thumbnailInline()) {
-			_thumbnail = blurred->pixBlurredSingle(_pixw, _pixh, st::linksPhotoSize, st::linksPhotoSize, roundRadius);
+			_thumbnail = blurred->pixSingle(size, args.blurred());
 			return;
 		} else {
 			return;
@@ -1880,7 +1917,7 @@ QSize Gif::countFrameSize() const {
 void Gif::clipCallback(Media::Clip::Notification notification) {
 	using namespace Media::Clip;
 	switch (notification) {
-	case NotificationReinit: {
+	case Notification::Reinit: {
 		if (_gif) {
 			if (_gif->state() == State::Error) {
 				_gif.setBad();
@@ -1891,14 +1928,10 @@ void Gif::clipCallback(Media::Clip::Notification notification) {
 						_gif->height());
 					_gif.reset();
 				} else {
-					auto height = st::inlineMediaHeight;
-					auto frame = countFrameSize();
-					_gif->start(
-						frame.width(),
-						frame.height(),
-						_width,
-						height,
-						ImageRoundRadius::None, RectPart::None);
+					_gif->start({
+						.frame = countFrameSize(),
+						.outer = { _width, st::inlineMediaHeight },
+					});
 				}
 			} else if (_gif->autoPausedGif()
 					&& !delegate()->itemVisible(this)) {
@@ -1909,7 +1942,7 @@ void Gif::clipCallback(Media::Clip::Notification notification) {
 		update();
 	} break;
 
-	case NotificationRepaint: {
+	case Notification::Repaint: {
 		if (_gif && !_gif->currentDisplayed()) {
 			update();
 		}
@@ -1930,12 +1963,11 @@ void Gif::validateThumbnail(
 	}
 	_thumbGood = good;
 	_thumb = image->pixNoCache(
-		frame.width() * cIntRetinaFactor(),
-		frame.height() * cIntRetinaFactor(),
-		(Images::Option::Smooth
-			| (good ? Images::Option::None : Images::Option::Blurred)),
-		size.width(),
-		size.height());
+		frame * style::DevicePixelRatio(),
+		{
+			.options = (good ? Images::Option() : Images::Option::Blur),
+			.outer = size,
+		});
 }
 
 void Gif::prepareThumbnail(QSize size, QSize frame) {
@@ -1981,26 +2013,20 @@ void Gif::paint(
 	}
 	const auto radial = isRadialAnimation();
 
-	int32 height = st::inlineMediaHeight;
-	QSize frame = countFrameSize();
-
-	QRect r(0, 0, _width, height);
+	const auto frame = countFrameSize();
+	const auto r = QRect(0, 0, _width, st::inlineMediaHeight);
 	if (animating) {
-		const auto pixmap = _gif->current(
-			frame.width(),
-			frame.height(),
-			_width,
-			height,
-			ImageRoundRadius::None,
-			RectPart::None,
-			/*context->paused ? 0 : */context->ms);
+		const auto pixmap = _gif->current({
+			.frame = frame,
+			.outer = r.size(),
+		}, /*context->paused ? 0 : */context->ms);
 		if (_thumb.isNull()) {
 			_thumb = pixmap;
 			_thumbGood = true;
 		}
 		p.drawPixmap(r.topLeft(), pixmap);
 	} else {
-		prepareThumbnail({ _width, height }, frame);
+		prepareThumbnail(r.size(), frame);
 		if (_thumb.isNull()) {
 			p.fillRect(r, st::overviewPhotoBg);
 		} else {
@@ -2028,7 +2054,11 @@ void Gif::paint(
 			return &st::historyFileInDownload;
 		}();
 		const auto size = st::overviewVideoRadialSize;
-		QRect inner((_width - size) / 2, (height - size) / 2, size, size);
+		QRect inner(
+			(r.width() - size) / 2,
+			(r.height() - size) / 2,
+			size,
+			size);
 		icon->paintInCenter(p, inner);
 		if (radial) {
 			p.setOpacity(1);
