@@ -9,18 +9,10 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 
 #include "core/crash_reports.h"
 #include "core/update_checker.h"
-
-#ifndef DESKTOP_APP_DISABLE_WEBKITGTK
 #include "webview/platform/linux/webview_linux_webkit2gtk.h"
-#endif // !DESKTOP_APP_DISABLE_WEBKITGTK
 
 #include <QtWidgets/QApplication>
 
-#ifndef DESKTOP_APP_DISABLE_DBUS_INTEGRATION
-#include <glibmm.h>
-#include <giomm.h>
-#endif // !DESKTOP_APP_DISABLE_DBUS_INTEGRATION
-
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -59,19 +51,12 @@ Launcher::Launcher(int argc, char *argv[])
 }
 
 int Launcher::exec() {
-#ifndef DESKTOP_APP_DISABLE_DBUS_INTEGRATION
-	Glib::init();
-	Gio::init();
-#endif // !DESKTOP_APP_DISABLE_DBUS_INTEGRATION
-
-#ifndef DESKTOP_APP_DISABLE_WEBKITGTK
 	for (auto i = begin(_arguments), e = end(_arguments); i != e; ++i) {
-		if (*i == "-webviewhelper" && std::distance(i, e) > 2) {
-			Webview::WebKit2Gtk::SetServiceName(*(i + 2));
-			return Webview::WebKit2Gtk::Exec(*(i + 1));
+		if (*i == "-webviewhelper" && std::distance(i, e) > 1) {
+			Webview::WebKit2Gtk::SetSocketPath(*(i + 1));
+			return Webview::WebKit2Gtk::Exec();
 		}
 	}
-#endif // !DESKTOP_APP_DISABLE_WEBKITGTK
 
 	return Core::Launcher::exec();
 }
