@@ -10,7 +10,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "platform/platform_file_utilities.h"
 #include "base/platform/base_platform_info.h"
 #include "base/platform/linux/base_linux_glibmm_helper.h"
-#include "platform/linux/linux_wayland_integration.h"
+#include "base/platform/linux/base_linux_wayland_integration.h"
 #include "storage/localstorage.h"
 #include "base/random.h"
 
@@ -20,7 +20,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include <glibmm.h>
 #include <giomm.h>
 
-using Platform::internal::WaylandIntegration;
+using base::Platform::WaylandIntegration;
 
 namespace Platform {
 namespace FileDialog {
