@@ -8,9 +8,14 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #pragma once
 
 #include "platform/platform_main_window.h"
+#include "base/unique_qptr.h"
 
 class QMenuBar;
 
+namespace Ui {
+class PopupMenu;
+} // namespace Ui
+
 namespace Platform {
 
 class MainWindow : public Window::MainWindow {
@@ -24,6 +29,8 @@ public:
 	~MainWindow();
 
 protected:
+	bool eventFilter(QObject *obj, QEvent *evt) override;
+
 	void initHook() override;
 	void unreadCounterChangedHook() override;
 	void updateGlobalMenuHook() override;
@@ -41,9 +48,7 @@ protected:
 	void psSetupTrayIcon();
 
 private:
-	class Private;
-	friend class Private;
-	const std::unique_ptr<Private> _private;
+	base::unique_qptr<Ui::PopupMenu> _trayIconMenuXEmbed;
 
 	QMenuBar *psMainMenu = nullptr;
 	QAction *psLogout = nullptr;
