@@ -14,6 +14,7 @@ https://github.com/telegramdesktop/tdesktop/blob/master/LEGAL
 #include "base/platform/mac/base_utilities_mac.h"
 #include "base/random.h"
 #include "history/history.h"
+#include "history/history_item.h"
 #include "ui/empty_userpic.h"
 #include "main/main_session.h"
 #include "mainwindow.h"
@@ -107,7 +108,7 @@ using Manager = Platform::Notifications::Manager;
 	}
 
 	NSNumber *msgObject = [notificationUserInfo objectForKey:@"msgid"];
-	const auto notificationMsgId = msgObject ? [msgObject intValue] : 0;
+	const auto notificationMsgId = msgObject ? [msgObject longLongValue] : 0LL;
 
 	const auto my = Window::Notifications::Manager::NotificationId{
 		.full = Manager::FullPeer{
@@ -186,6 +187,7 @@ public:
 		const QString &msg,
 		DisplayOptions options);
 	void clearAll();
+	void clearFromItem(not_null<HistoryItem*> item);
 	void clearFromHistory(not_null<History*> history);
 	void clearFromSession(not_null<Main::Session*> session);
 	void updateDelegate();
@@ -207,6 +209,9 @@ private:
 	std::mutex _clearingMutex;
 	std::condition_variable _clearingCondition;
 
+	struct ClearFromItem {
+		NotificationId id;
+	};
 	struct ClearFromHistory {
 		FullPeer fullPeer;
 	};
@@ -218,6 +223,7 @@ private:
 	struct ClearFinish {
 	};
 	using ClearTask = std::variant<
+		ClearFromItem,
 		ClearFromHistory,
 		ClearFromSession,
 		ClearAll,
@@ -268,7 +274,7 @@ void Manager::Private::showNotification(
 			@"session",
 			[NSNumber numberWithUnsignedLongLong:peer->id.value],
 			@"peer",
-			[NSNumber numberWithInt:msgId.bare],
+			[NSNumber numberWithLongLong:msgId.bare],
 			@"msgid",
 			[NSNumber numberWithUnsignedLongLong:_managerId],
 			@"manager",
@@ -305,6 +311,7 @@ void Manager::Private::clearingThreadLoop() {
 	auto finished = false;
 	while (!finished) {
 		auto clearAll = false;
+		auto clearFromItems = base::flat_set<NotificationId>();
 		auto clearFromPeers = base::flat_set<FullPeer>();
 		auto clearFromSessions = base::flat_set<uint64>();
 		{
@@ -318,6 +325,8 @@ void Manager::Private::clearingThreadLoop() {
 					clearAll = true;
 				}, [&](ClearAll) {
 					clearAll = true;
+				}, [&](const ClearFromItem &value) {
+					clearFromItems.emplace(value.id);
 				}, [&](const ClearFromHistory &value) {
 					clearFromPeers.emplace(value.fullPeer);
 				}, [&](const ClearFromSession &value) {
@@ -335,17 +344,21 @@ void Manager::Private::clearingThreadLoop() {
 			if (!notificationSessionId) {
 				return true;
 			}
-			if (NSNumber *peerObject = [notificationUserInfo objectForKey:@"peer"]) {
-				const auto notificationPeerId = [peerObject unsignedLongLongValue];
-				if (notificationPeerId) {
-					return clearFromSessions.contains(notificationSessionId)
-						|| clearFromPeers.contains(FullPeer{
-							.sessionId = notificationSessionId,
-							.peerId = PeerId(notificationPeerId)
-						});
-				}
+			NSNumber *peerObject = [notificationUserInfo objectForKey:@"peer"];
+			const auto notificationPeerId = peerObject ? [peerObject unsignedLongLongValue] : 0;
+			if (!notificationPeerId) {
+				return true;
 			}
-			return true;
+			NSNumber *msgObject = [notificationUserInfo objectForKey:@"msgid"];
+			const auto msgId = msgObject ? [msgObject longLongValue] : 0LL;
+			const auto full = FullPeer{
+				.sessionId = notificationSessionId,
+				.peerId = PeerId(notificationPeerId)
+			};
+			const auto id = NotificationId{ full, MsgId(msgId) };
+			return clearFromSessions.contains(notificationSessionId)
+				|| clearFromPeers.contains(full)
+				|| (msgId && clearFromItems.contains(id));
 		};
 
 		NSUserNotificationCenter *center = [NSUserNotificationCenter defaultUserNotificationCenter];
@@ -380,6 +393,13 @@ void Manager::Private::clearAll() {
 	putClearTask(ClearAll());
 }
 
+void Manager::Private::clearFromItem(not_null<HistoryItem*> item) {
+	putClearTask(ClearFromItem { FullPeer{
+		.sessionId = item->history()->session().uniqueId(),
+		.peerId = item->history()->peer->id
+	}, item->id });
+}
+
 void Manager::Private::clearFromHistory(not_null<History*> history) {
 	putClearTask(ClearFromHistory { FullPeer{
 		.sessionId = history->session().uniqueId(),
@@ -434,6 +454,10 @@ void Manager::doClearAllFast() {
 	_private->clearAll();
 }
 
+void Manager::doClearFromItem(not_null<HistoryItem*> item) {
+	_private->clearFromItem(item);
+}
+
 void Manager::doClearFromHistory(not_null<History*> history) {
 	_private->clearFromHistory(history);
 }
