@@ -22,6 +22,9 @@ inline bool AutostartSupported() {
 	return false;
 }
 
+inline void AutostartRequestStateFromSystem(Fn<void(bool)> callback) {
+}
+
 inline bool TrayIconSupported() {
 	return true;
 }
@@ -50,7 +53,6 @@ inline void psCheckLocalSocket(const QString &serverName) {
 
 void psActivateProcess(uint64 pid = 0);
 QString psAppDataPath();
-void psAutoStart(bool start, bool silent = false);
 void psSendToMenu(bool send, bool silent = false);
 
 int psCleanup();
